#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


imagedir = "src"
files = [ "triangle.ptx" ]
for f in files:
    command += info_command (imagedir + "/" + f)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import
import os
import OpenImageIO as oiio


try:
    config = oiio.ColorConfig()
    print ("getNumColorSpaces =", config.getNumColorSpaces())
    print ("getColorSpaceNames =", config.getColorSpaceNames())
    print ("Index of 'lin_srgb' =", config.getColorSpaceIndex('lin_srgb'))
    print ("Index of 'unknown' =", config.getColorSpaceIndex('unknown'))
    print ("Name of color space 2 =", config.getColorSpaceNameByIndex(2))
    print ("getNumLooks =", config.getNumLooks())
    print ("getLookNames =", config.getLookNames())

    print ("getNumDisplays =", config.getNumDisplays())
    print ("getDisplayNames =", config.getDisplayNames())
    print ("getDefaultDisplayName =", config.getDefaultDisplayName())

    print ("getNumViews =", config.getNumViews())
    print ("getViewNames =", config.getViewNames())
    print ("getDefaultViewName =", config.getDefaultViewName())

    print ("getNumRoles =", config.getNumRoles())
    print ("getRoles =", config.getRoles())

    print ("aliases of 'scene_linear' are", config.getAliases("scene_linear"))

    print ("resolve('foo'):", config.resolve("foo"))
    print ("resolve('linear'):", config.resolve("linear"))
    print ("resolve('scene_linear'):", config.resolve("scene_linear"))
    print ("resolve('lin_srgb'):", config.resolve("lin_srgb"))
    print ("resolve('srgb'):", config.resolve("srgb"))
    print ("resolve('ACEScg'):", config.resolve("ACEScg"))
    print ("equivalent('lin_srgb', 'srgb'):", config.equivalent("lin_srgb", "srgb"))
    print ("equivalent('scene_linear', 'srgb'):", config.equivalent("scene_linear", "srgb"))
    print ("equivalent('linear', 'lin_srgb'):", config.equivalent("scene_linear", "lin_srgb"))
    print ("equivalent('scene_linear', 'lin_srgb'):", config.equivalent("scene_linear", "lin_srgb"))
    print ("equivalent('ACEScg', 'scene_linear'):", config.equivalent("ACEScg", "scene_linear"))
    print ("equivalent('lnf', 'scene_linear'):", config.equivalent("lnf", "scene_linear"))
    print ("")

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Adjust error thresholds a tad to account for platform-to-platform variation
# in some math precision.
hardfail = 0.16
failpercent = 0.001
allowfailures = 1

command = testtex_command ("../oiio-images/miplevels.tx",
                           extraargs = "--stochastic 3 -bluenoise -d uint8 -o out.tif")
outputs = [ "out.tif" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/v2/Stereo"

# Multi-part, not deep
command += rw_command (imagedir, "composited.exr", use_oiiotool=1,
                       preargs="--stats")

# Multi-part and also deep
command += rw_command (imagedir, "Balls.exr", use_oiiotool=1,
                       preargs="--stats")

# Convert from scanline to tiled
command += rw_command (imagedir, "Leaves.exr", use_oiiotool=1,
                       extraargs="--tile 64 64 ", preargs="--stats")

# Check a complicated multipart example
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Beachball"
files = [ "multipart.0001.exr" ]
for f in files:
    command += rw_command (imagedir, f, use_oiiotool=1, extraargs="-a")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import
import OpenImageIO as oiio
import numpy as np


#######################################################
# Create an exr file with deliberately missing tiles

tilesize = 64
res = 256
tile = np.ones((tilesize,tilesize,3), dtype='float') * 0.75

spec = oiio.ImageSpec(res, res, 3, "half")
spec.tile_width = tilesize
spec.tile_height = tilesize
spec.attribute('openexr:lineOrder', 'randomY')

out = oiio.ImageOutput.create ('partial.exr')
if not out :
    print ('Could not create ImageOutput: ', oiio.geterror())
ok = out.open ('partial.exr', spec)
if not ok :
    print ('Could not open file: ', out.geterror())
count = 0
for y in range(0,res,tilesize) :
    for x in range(0,res,tilesize) :
        # Skip every 7th tile
        if (count % 7) > 1 :
            ok = out.write_tile (x, y, 0, tile)
            if not ok :
                print ('Could not write tile y={} x={}: {}'.format(y, x, out.geterror()))
        count += 1

out.close()




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


####################################################################
# This test exercises oiiotool functionality that is mostly about
# copying pixels from one image to another.
####################################################################

# Capture error output
redirect = " >> out.txt 2>&1 "

# Create some test images we need
command += oiiotool("-pattern constant:color=.25,.5,.75 64x64 3 -d half -o rgb64.exr")
command += oiiotool("-pattern constant:color=.25,.5,.75 64x64 3 -pattern constant:color=42 64x64 1 --chnames Z --siappend -d half -o rgb-z-parts64.exr")


# Test -i to read specific channels
# Note: this used to crash until PR #3513
command += oiiotool("-i:ch=R,G rgb64.exr -o rgonly.exr")
# Test -i to read nonexistent channels
command += oiiotool("-i:ch=Z rgb64.exr -d half -o ch-err.exr")
# Test -i to read nonexistent channels in one subimage of a multi-subimage file
command += oiiotool("-i:ch=R,G,B rgb-z-parts64.exr -d half -o ch-err2.exr")


# test -d to change data formats
command += oiiotool ("src/rgbaz.exr -d half -o allhalf.exr")
command += info_command ("allhalf.exr", safematch=1)

# test -d NAME=fmt to change data format of one channel, and to make
# sure oiiotool will output per-channel formats.
command += oiiotool ("src/rgbaz.exr -d half -d Z=float -o rgbahalf-zfloat.exr")
command += info_command ("rgbahalf-zfloat.exr", safematch=1)


# Some tests to verify that we are transferring data formats properly.
#
command += oiiotool ("-pattern checker 128x128 3 -d uint8 -tile 16 16 -o uint8.tif " +
                     "-echo \"explicit -d uint save result: \" -metamatch \"width|tile\" -i:info=2 uint8.tif -echo \"\"")
# Un-modified copy should preserve data type and tiling
command += oiiotool ("uint8.tif -o tmp.tif " +
                     "-echo \"unmodified copy result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")
# Copy with explicit data request should change data type
command += oiiotool ("uint8.tif -d uint16 -o copy_uint16.tif " +
                     "-echo \"copy with explicit -d uint16 result: \" -metamatch \"width|tile\" -i:info=2 copy_uint16.tif -echo \"\"")
# Copy with data request in the -o
command += oiiotool ("uint8.tif -o:type=uint16 copy_uint16-o.tif " +
                     "-i copy_uint16-o.tif " +
                     "-echo \"copy with -o:type=uint16 result: \" -printinfo:native=1:verbose=0")
command += oiiotool ("uint8.tif -o:datatype=uint16 copy_uint16-o.tif " +
                     "-i copy_uint16-o.tif " +
                     "-echo \"copy with -o:datatype=uint16 result: \" -printinfo:native=1:verbose=0")
# Subimage concatenation should preserve data type
command += oiiotool ("uint8.tif copy_uint16.tif -siappend -o tmp.tif " +
                     "-echo \"siappend result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")
# Combining two images preserves the format of the first read input, if
# there are not any other hints:
command += oiiotool ("-pattern checker 128x128 3 uint8.tif -add -o tmp.tif " +
                     "-echo \"combining images result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")

# Try to copy extra channels to a file that doesn't support it -- we should get
# a warning message about only saving the first 3 channels.
command += oiiotool ("--pattern constant:color=0.1,0.2,0.3,0.4 64x64 4 --chnames R,G,B,X -d uint8 -o rgbx.png")


# test channel shuffling
command += oiiotool ("../common/grid.tif"
            + " --ch =0.25,B,G -o chanshuffle.tif")

# test --ch to separate RGBA from an RGBAZ file
command += oiiotool ("src/rgbaz.exr --ch R,G,B,A -o ch-rgba.exr")
command += oiiotool ("src/rgbaz.exr --ch Z -o ch-z.exr")

# test --chappend to merge RGBA and Z
command += oiiotool ("ch-rgba.exr ch-z.exr --chappend -o chappend-rgbaz.exr")

# test --chnames to rename channels
command += oiiotool ("src/rgbaz.exr --chnames Red,,,,Depth -o chname.exr")
command += info_command ("chname.exr", safematch=1)

# test --crop
command += oiiotool ("../common/grid.tif --crop 100x400+50+200 -o crop.tif")

# test --cut
command += oiiotool ("../common/grid.tif --cut 100x400+50+200 -o cut.tif")

# test --paste
command += oiiotool ("../common/grid.tif "
            + "--pattern checker 256x256 3 --paste +150+75 -o pasted.tif")

# test --pastemeta
command += oiiotool ("--pattern:type=half constant:color=0,1,0 64x64 3 -o green.exr")
command += oiiotool ("--pattern:type=half constant:color=1,0,0 64x64 3 -attrib hair brown -attrib eyes 2 -attrib weight 20.5 -o redmeta.exr")
command += oiiotool ("redmeta.exr green.exr --pastemeta -o greenmeta.exr")
command += info_command ("green.exr", safematch=True)
command += info_command ("greenmeta.exr", safematch=True)

# test mosaic
# Purposely test with fewer images than the mosaic array size
command += oiiotool ("--pattern constant:color=1,0,0 50x50 3 "
            + "--pattern constant:color=0,1,0 50x50 3 "
            + "--pattern constant:color=0,0,1 50x50 3 "
            + "--mosaic:pad=10 2x2 -d uint8 -o mosaic.tif")

# Test --mosaic with --fit
command += oiiotool ("--pattern constant:color=1,.1,.1 50x50 3 "
            + "--pattern constant:color=0.1,1,0.1 500x300 3 "
            + "--pattern constant:color=0.1,0.1,1 10x16 3 "
            + "--mosaic:pad=10:fit=64x64 2x2 -d uint8 -o mosaicfit.tif")


# test --metamerge, using chappend as an example
command += oiiotool ("--create 64x64 3 -chnames R,G,B -attrib a 3.0 -o aimg.exr")
command += oiiotool ("--create 64x64 3 -chnames A,Z -attrib b 1.0 -o bimg.exr")
command += oiiotool ("aimg.exr bimg.exr --chappend -o nometamerge.exr")
command += oiiotool ("--metamerge aimg.exr bimg.exr --chappend -o metamerge.exr")
command += info_command ("nometamerge.exr", safematch=True)
command += info_command ("metamerge.exr", safematch=True)

# test --chappend of multiple images
command += oiiotool ("--pattern constant:color=0.5 64x64 1 --text R --chnames R " +
                     "--pattern constant:color=0.25,0.75 64x64 2 --text G,B --chnames G,B " +
                     "--pattern constant:color=1.0 64x64 1 --text A --chnames A " +
                     "--chappend:n=3 -d half -o chappend-3images.exr")


# Interesting error cases
command += oiiotool ("-echo \"Testing -o with no image\" -o out.tif")


# Outputs to check against references
outputs = [
            "rgonly.exr", "ch-err.exr", "ch-err2.exr",
            "allhalf.exr", "rgbahalf-zfloat.exr",
            "chanshuffle.tif", "ch-rgba.exr", "ch-z.exr",
            "chappend-rgbaz.exr", "chname.exr",
            "crop.tif", "cut.tif", "pasted.tif",
            "mosaic.tif", "mosaicfit.tif",
            "greenmeta.exr",
            "chappend-3images.exr",
            "out.txt"
          ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Miscellaneous TIFF-related tests

# save the error output
redirect = " >> out.txt 2>&1 "

# Regression test -- we once had a bug where 'separate' planarconfig
# tiled float files would have data corrupted by a buffer overwrite.
command += oiiotool("--pattern checker 128x128 4 --tile 64 64 --planarconfig separate -d float -o check1.tif")

# Test bug we had until OIIO 2.3 when reading planarconfig=separate files
# (fixed by #2757) that was not detected by the uncompressed file. So copy
# to force compression in order to properly test:
command += rw_command ("src", "separate.tif")

# Test bugs we had until OIIO 2.4 for these corrupt file
command += oiiotool ("--oiioattrib try_all_readers 0 --info -v src/corrupt1.tif", failureok = True)
command += oiiotool ("--oiioattrib try_all_readers 0 --info -v src/crash-1633.tif", failureok = True)
command += oiiotool ("--oiioattrib try_all_readers 0 --info src/crash-1643.tif -o out.exr", failureok = True)
command += iconvert ("src/crash-1709.tif crash-1709.exr", failureok=True)

outputs = [ "check1.tif", "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import


############################################################################
# This file contains code examples from the TextureSystem chapter of the
# main OpenImageIO documentation.
#
# To add an additional test, replicate the section below. Change
# "example1" to a helpful short name that identifies the example.


# BEGIN-texturesys-example1
import OpenImageIO as oiio
import numpy as np

def example1() :
    #
    # Example code fragment from the docs goes here.
    #
    # It probably should generate either some text output (which will show up
    # in "out.txt" that captures each test's output), or it should produce a
    # (small) image file that can be compared against a reference image that
    # goes in the ref/ subdirectory of this test.
    #
    return

# END-texturesys-example1

#
############################################################################





if __name__ == '__main__':
    # Each example function needs to get called here, or it won't execute
    # as part of the test.
    example1()



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

files = ["gif_animation.gif", "gif_oiio_logo_with_alpha.gif",
         "gif_tahoe.gif", "gif_tahoe_interlaced.gif",
         "gif_bluedot.gif", "gif_diagonal_interlaced.gif",
         "gif_triangle_interlaced.gif", "gif_test_disposal_method.gif",
         "gif_test_loop_count.gif"]
for f in files:
    command += info_command (OIIO_TESTSUITE_IMAGEDIR + "/" + f)

# Test write / conversion to GIF
command += oiiotool (OIIO_TESTSUITE_ROOT+"/common/tahoe-tiny.tif -o tahoe-tiny.gif")
command += info_command ("tahoe-tiny.gif")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


files = [ "checker.cin" ]
for f in files:
    command += info_command ("../oiio-images/cineon/" + f)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


from __future__ import print_function
from __future__ import absolute_import
import OpenImageIO as oiio
import sys

if len(sys.argv) < 3 :
    print("No filenames specified")
    exit(1)

inname = sys.argv[1]
outname = sys.argv[2]
buf = oiio.ImageBuf(inname)
if buf.has_thumbnail :
    th = buf.get_thumbnail()
    th.write(outname, dtype='uint8')



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command += oiiotool ("-pattern constant:color=.5,.1,.1 256x256 3 -text:size=50:x=75:y=140 1001 --attrib Make pet --attrib Model dog -d uint8 -otex file.1001.tx")
command += oiiotool ("-pattern constant:color=.1,.5,.1 256x256 3 -text:size=50:x=75:y=140 1002 --attrib Make pet --attrib Model dog -d uint8 -otex file.1002.tx")
# force DateTime to differ in these files
command += "sleep 1 ; "
command += oiiotool ("-pattern constant:color=.1,.1,.5 256x256 3 -text:size=50:x=75:y=140 1011 --attrib Make pet --attrib Model cat -d uint8 -otex file.1011.tx")
command += oiiotool ("-pattern constant:color=.1,.5,.5 256x256 3 -text:size=50:x=75:y=140 1012 --attrib Make pet --attrib Model dog -d uint8 -otex file.1012.tx")
command += oiiotool ("-pattern constant:color=.1,.5,.5 256x256 3 -text:size=50:x=75:y=140 1032 --attrib Make pet --attrib Model dog -d uint8 -otex file.1032.tx")

command += testtex_command ("\"file.<UDIM>.tx\"",
                            "-nowarp -scalest 2 2 -res 128 128 -d uint8 -o out.tif")

# Test get_texture_info on one thing that should be identical across all
# the tiles, and one thing that should not be.
command += testtex_command ("\"file.<UDIM>.tx\" --gettextureinfo Make --iters 0")
command += testtex_command ("\"file.<UDIM>.tx\" --gettextureinfo Model --iters 0")

# Test the other form of single-index udim pattern
command += testtex_command ("\"file.%(UDIM)d.tx\"",
                            "-nowarp -scalest 2 2 -res 128 128 -d uint8 -o out2.tif")
command += testtex_command ("\"file.%(UDIM)d.tx\" --gettextureinfo Make --iters 0")
command += testtex_command ("\"file.%(UDIM)d.tx\" --gettextureinfo Model --iters 0")

# Exercise making making temp files, and having low file and tile limits
command += testtex_command ("--udim --maketests 10 \"mktest_{:04}.<UDIM>.tx\""
                            + " --maketest-res 1024 --cachesize 1 --maxfiles 5"
                            + " --res 256 256 -d uint8 -o out3.tif")

outputs = [ "out.tif", "out2.tif", "out3.tif", "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Test oiiotool's ability to add and delete attributes


# Test --eraseattrib ability to erase one specific attribute
# The result should not have "Make"
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib Make -o nomake.jpg")
command += info_command ("nomake.jpg", safematch=True)

# Test --eraseattrib ability to match patterns
# The result should have no GPS tags
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib \"GPS:.*\" -o nogps.jpg")
command += info_command ("nogps.jpg", safematch=True)

# Test --eraseattrib ability to strip all attribs
# The result should be very minimal
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib \".*\" -o noattribs.jpg")
command += info_command ("noattribs.jpg", safematch=True)

# Test keywords
command += oiiotool ("../common/tahoe-tiny.tif --echo \"initial keywords={TOP[keywords]}\" " +
                     "--keyword foo --keyword bar " +
                     "--echo \"after adding, keywords={TOP[keywords]}\" " +
                     "--clear-keywords " +
                     "--echo \"after clearing, keywords={TOP[keywords]}\" ")

# Test --origin and --originoffset
command += oiiotool ('--create 64x64 3 --origin +10+20 ' +
                     '--echo "after --origin, {TOP.geom}" ' +
                     '--originoffset +100+200 ' +
                     '--echo "after --originoffset, {TOP.geom}"')

# Test adding and erasing attribs to multiple subimages
command += oiiotool ("--create 64x64 3 -dup --siappend " +
                     "--attrib:allsubimages=1 foo bar -d half -o attrib2.exr")
command += info_command ("attrib2.exr", safematch=True)
command += oiiotool ("attrib2.exr " +
                     "--eraseattrib:allsubimages=1 foo -d half -o attrib0.exr")
command += info_command ("attrib0.exr", safematch=True)

# Test adding and extracting ICC profiles
command += oiiotool ("../common/tahoe-tiny.tif --iccread ref/test.icc -o tahoe-icc.jpg")
command += info_command ("tahoe-icc.jpg", safematch=True)
command += oiiotool ("tahoe-icc.jpg --iccwrite test.icc")

outputs = [
            "test.icc",
            "out.txt"
]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Create some test images we need
# command += oiiotool ("--create 320x240 3 -d uint8 -o black.tif")
# command += oiiotool ("--pattern constant:color=0.5,0.5,0.5 128x128 3 -d half -o grey128.exr")
# command += oiiotool ("--pattern constant:color=0.5,0.5,0.5 64x64 3 -d half -o grey64.exr")
# command += oiiotool ("--create 256x256 3 --fill:color=1,.5,.5 256x256 --fill:color=0,1,0 80x80+100+100 -d uint8 -o filled.tif")
# wrapper_cmd = "time"
redirect += " 2>&1"
failureok = True

# test expression substitution
command += oiiotool ('-echo "42+2 = {42+2}" ' +
                     '-echo "42-2 = {42-2}" ' +
                     '-echo "42*2 = {42*2}" ' +
                     '-echo "42/2 = {42/2}"')

command += oiiotool ('-echo "42<41 = {42<41}" ' +
                     '-echo "42<42 = {42<42}" ' +
                     '-echo "42<43 = {42<43}" ' +
                     '-echo "42<=41 = {42<=41}" ' +
                     '-echo "42<=42 = {42<=42}" ' +
                     '-echo "42<=43 = {42<=43}" ' +
                     '-echo "42>41 = {42>41}" ' +
                     '-echo "42>42 = {42>42}" ' +
                     '-echo "42>43 = {42>43}" ' +
                     '-echo "42>=41 = {42>=41}" ' +
                     '-echo "42>=42 = {42>=42}" ' +
                     '-echo "42>=43 = {42>=43}" ' +
                     '-echo "42==41 = {42==41}" ' +
                     '-echo "42==42 = {42==42}" ' +
                     '-echo "42==43 = {42==43}" ' +
                     '-echo "42!=41 = {42!=41}" ' +
                     '-echo "42!=42 = {42!=42}" ' +
                     '-echo "42!=43 = {42!=43}" ' +
                     '-echo "42<=>41 = {42<=>41}" ' +
                     '-echo "42<=>42 = {42<=>42}" ' +
                     '-echo "42<=>43 = {42<=>43}" ')

command += oiiotool ('-echo "(1==2)&&(2==2) = {(1==2)&&(2==2)}" ' +
                     '-echo "(1==1)&&(2==2) = {(1==1)&&(2==2)}" ' +
                     '-echo "(1==2)&&(1==2) = {(1==2)&&(1==2)}" ' +
                     '-echo "(1==2)||(2==2) = {(1==2)||(2==2)}" ' +
                     '-echo "(1==1)||(2==2) = {(1==1)||(2==2)}" ' +
                     '-echo "(1==2)||(1==2) = {(1==2)||(1==2)}" ' +
                     '-echo "not(1==1) = {not(1==1)}" ' +
                     '-echo "not(1==2) = {not(1==2)}" ' +
                     '-echo "!(1==1) = {!(1==1)}" ' +
                     '-echo "!(1==2) = {!(1==2)}"')

command += oiiotool ('-echo "eq(foo,foo) = {eq(\'foo\',\'foo\')}" ' +
                     '-echo "eq(foo,bar) = {eq(\'foo\',\'bar\')}" ' +
                     '-echo "neq(foo,foo) = {neq(\'foo\',\'foo\')}" ' +
                     '-echo "neq(foo,bar) = {neq(\'foo\',\'bar\')}"')

command += oiiotool ('-echo "16+5={16+5}" -echo "16-5={16-5}" -echo "16*5={16*5}"')
command += oiiotool ('-echo "16/5={16/5}" -echo "16//5={16//5}" -echo "16%5={16%5}"')
command += oiiotool ("../common/tahoe-small.tif --pattern fill:top=0,0,0,0:bottom=0,0,1,1 " +
                     "{TOP.geom} {TOP.nchannels} -d uint8 -o exprgradient.tif")
command += oiiotool ('../common/tahoe-small.tif -cut "{TOP.width-20* 2}x{TOP.height-40+(4*2- 2 ) /6-1}+{TOP.x+100.5-80.5 }+{TOP.y+20}" -d uint8 -o exprcropped.tif')
command += oiiotool ('../common/tahoe-small.tif -o exprstrcat{TOP.compression}.tif')
command += oiiotool ('../common/tahoe-tiny.tif -subc "{TOP.MINCOLOR}" -divc "{TOP.MAXCOLOR}" -o tahoe-contraststretch.tif')
# test use of quotes inside evaluation, {TOP.foo/bar} would ordinarily want
# to interpret '/' for division, but we want to look up metadata called
# 'foo/bar'.
command += oiiotool ("-create 16x16 3 -attrib \"foo/bar\" \"xyz\" -echo \"{TOP.'foo/bar'} should say xyz\"")
command += oiiotool ("-create 16x16 3 -attrib smpte:TimeCode \"01:02:03:04\" -echo \"timecode is {TOP.'smpte:TimeCode'}\"")

# Ensure that --evaloff/--evalon work
command += oiiotool ("-echo \"{1+1}\" --evaloff -echo \"{3+4}\" --evalon -echo \"{2*2}\"")

# Test user variables
command += oiiotool ('-echo "Testing --set, expr i:" -set i 1 -echo "  i = {i}" -set i "{i+41}" -echo "  now i = {i}"')
command += oiiotool ('-echo "Testing --set, expr var(i):" -set i 1 -echo "  i = {var(i)}" -set i "{i+41}" -echo "  now i = {var(i)}"')
command += oiiotool ('-echo "Testing --set of implied types:" ' +
                     '-set i 42 -set f 3.5 ' +
                     '-set s "hello world" ' +
                     '-echo "  i = {i}, f = {f}, s = {s}"')
command += oiiotool ('-echo "Testing --set of various explicit types:" ' +
                     '-set:type=int i 42 -set:type=float f 3.5 ' +
                     '-set:type=string s "hello world" ' +
                     '-set:type="string[3]" sarr "hello","world","wide" ' +
                     '-set:type=timecode tc 01:02:03:04 ' +
                     '-set:type=rational rat 1/2 ' +
                     '-echo "  i = {i}, f = {f}, s = {s}, tc = {tc}, rat = {rat}"')

# Test getattribute in an expression
command += oiiotool ('-echo "Expr getattribute(\"limits:channels\") = {getattribute(\"limits:channels\")}"')

# Test --if --else --endif
command += oiiotool ('-echo "Testing if with true cond (expect output):" -set i 42 -if "{i}" -echo "  inside if clause, i={i}" -endif -echo "  done" -echo " "')
command += oiiotool ('-echo "Testing if with false cond (expect NO output):" -set i 0 -if "{i}" -echo "  inside if clause, i={i}" -endif -echo "  done" -echo " "')
command += oiiotool ('-echo "Testing if/else with true cond:" -set i 42 -if "{i}" -echo "  inside if clause, i={i}" -else -echo "  inside else clause, i={i}" -endif -echo "  done" -echo " "')
command += oiiotool ('-echo "Testing if/else with false cond:" -set i 0 -if "{i}" -echo "  inside if clause, i={i}" -else -echo "  inside else clause, i={i}" -endif -echo "  done" -echo " "')
command += oiiotool ('-echo "Testing else without if:" -else -echo "bad" -endif -echo " "')
command += oiiotool ('-echo "Testing endif without if:" -endif -echo " "')

# Test --while --endwhile
command += oiiotool ('-echo "Testing while (expect output 0..2):" -set i 0 --while "{i < 3}" --echo "  i = {i}" --set i "{i+1}" --endwhile -echo " "')
command += oiiotool ('-echo "Testing endwhile without while:" -endwhile -echo " "')

# Test --for --endfor
command += oiiotool ('-echo "Testing for i 5 (expect output 0..4):" --for i 5 --echo "  i = {i}" --endfor -echo " "')
command += oiiotool ('-echo "Testing for i 5,10 (expect output 5..9):" --for i 5,10 --echo "  i = {i}" --endfor -echo " "')
command += oiiotool ('-echo "Testing for i 5,10,2 (expect output 5,7,9):" --for i 5,10,2 --echo "  i = {i}" --endfor -echo " "')
command += oiiotool ('-echo "Testing endfor without for:" -endfor -echo " "')
command += oiiotool ('-echo "Testing for i 5,10,2,8 (bad range):" --for i 5,10,2,8 --echo "  i = {i}" --endfor -echo " "')

# test sequences
command += oiiotool ("../common/tahoe-tiny.tif -o copyA.1-10#.jpg")
command += oiiotool ("--debug copyA.#.jpg -o copyB.#.jpg")
command += oiiotool (" --info  " +  " ".join(["copyA.{0:04}.jpg".format(x) for x in range(1,11)]))
command += oiiotool ("--frames 1-5 --echo \"Sequence 1-5:  {FRAME_NUMBER}\"")
command += oiiotool ("--frames -5-5 --echo \"Sequence -5-5:  {FRAME_NUMBER}\"")
command += oiiotool ("--frames -5--2 --echo \"Sequence -5--2:  {FRAME_NUMBER}\"")

# Sequence errors:
# No matching files found
command += oiiotool ("notfound.#.jpg -o alsonotfound.#.jpg")
# Ranges don't match
command += oiiotool ("copyA.#.jpg -o copyC.1-5#.jpg")

# Test stats and metadata expression substitution
command += oiiotool ("../common/tahoe-tiny.tif"
                     + " --echo \"\\nBrief: {TOP.METABRIEF}\""
                     + " --echo \"\\nBrief native: {TOP.METANATIVEBRIEF}\""
                     + " --echo \"\\nMeta native: {TOP.METANATIVE}\""
                     + " --echo \"\\nStats:\\n{TOP.STATS}\\n\"")

# Test IMG[]
command += oiiotool ("../common/tahoe-tiny.tif ../common/tahoe-small.tif " +
                     "--echo \"Stack holds [0] = {IMG[0].filename}, [1] = {IMG[1].filename}\"")

# Test some special attribute evaluation names
command += oiiotool ("../common/tahoe-tiny.tif " +
                     "--echo \"filename={TOP.filename} file_extension={TOP.file_extension} file_noextension={TOP.file_noextension}\" " +
                     "--echo \"MINCOLOR={TOP.MINCOLOR} MAXCOLOR={TOP.MAXCOLOR} AVGCOLOR={TOP.AVGCOLOR}\"")

command += oiiotool (
    "--echo \"Testing NIMAGES:\" " +
    "--echo \"  {NIMAGES}\" " +
    "--create 16x16 3 " +
    "--echo \"  {NIMAGES}\" " +
    "--create 16x16 3 " +
    "--echo \"  {NIMAGES}\" " +
    "--create 16x16 3 " +
    "--echo \"  {NIMAGES}\" ")

# Test "postpone_callback" with an "image -BINOP image" operation instead of
# "image image -BINOP".
command += oiiotool ("../common/tahoe-tiny.tif -sub ../common/tahoe-tiny.tif "
                     + "-echo \"postponed sub:\" --printinfo:stats=1:verbose=0")

# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [
            "exprgradient.tif", "exprcropped.tif", "exprstrcatlzw.tif",
            "tahoe-contraststretch.tif",
            "out.txt" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Creates a texture with overscan -- it looks like the usual grid in the
# 0-1 (display) window, but is red checker for a while outside that window.
#
# We then make two images using that texture:
# 1. out-exact.exr just straight maps the [0,1] range, and should look like
#    the whole grid and nothing but the grid.
# 2. out-over.exr maps the [-0.5,1.5] range, so you should see the grid,
#    surrounded by the red check border, surrounded by black. The grid
#    itself should be the "middle half" of the image.

command += oiiotool("../common/grid.tif"
            + " -resize 512x512 "
            + " -pattern checker:color1=1,0,0:color2=.25,0,0 640x640 3 "
            + "-origin -64-64 -paste +0+0 -fullsize 512x512+0+0 -o overscan-src.exr")
command += maketx_command("overscan-src.exr", "grid-overscan.exr",
                          "--filter lanczos3", silent=True)
command += testtex_command ("grid-overscan.exr",
                            "--res 256 256 --wrap black --nowarp -o out-exact.exr",
                            silent=True)
command += testtex_command ("grid-overscan.exr",
                            "--res 256 256 --wrap black --nowarp " +
                            "--offset -0.5 -0.5 0 --scalest 2 2 " +
                            "-o out-over.exr", silent=True)
command += testtex_command ("grid-overscan.exr",
                            "--res 256 256 --wrap clamp --nowarp " +
                            "--offset -0.5 -0.5 0 --scalest 2 2 " +
                            "-o out-overclamp.exr", silent=True)

outputs = [ "out-exact.exr", "out-over.exr", "out-overclamp.exr" ]




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


redirect = ">> out.txt 2>&1"

# basic
command += testtex_command("-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "../openvdb/src/sphere.vdb -o out.exr")

# handles, derivatives
command += testtex_command("--handle --derivs --no-gettextureinfo "
                           "-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-o out-handle.exr ../openvdb/src/sphere.vdb")

# more channels
command += testtex_command("-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-nchannels 5 --no-gettextureinfo ../openvdb/src/sphere.vdb -o out-5chan.exr")

# subimages
command += testtex_command("-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-subimage 0 --no-gettextureinfo ../openvdb/src/sphere.vdb -o out-subimage0.exr")
command += testtex_command("-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-subimagename density --no-gettextureinfo ../openvdb/src/sphere.vdb -o out-subimagedensity.exr")
command += testtex_command("-res 2 2 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-subimagename missing --no-gettextureinfo ../openvdb/src/sphere.vdb -o out-subimagemissing.exr")

# interp and mip modes
command += testtex_command("-res 128 128 --nowarp --offset 5 5 5 --scalest 3 3 "
                           "-interpmode 0 --no-gettextureinfo "
                           "../openvdb/src/sphere.vdb -o closest.exr")

outputs = [ "out.exr",
            "out-handle.exr",
            "out-5chan.exr",
            "out-subimage0.exr",
            "out-subimagedensity.exr",
            "out-subimagemissing.exr",
            "closest.exr",
            "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command += info_command ("-s --stats ../common/textures/grid.tx", info_program="iinfo")

# command += oiiotool ("-pattern constant:color=0.25,0.5,0.75 4x4 3 --origin +2+2 --fullsize 20x20+1+1 -o tiny-az.exr")
command += info_command ("-f -v --hash --stats src/tiny-az.exr", info_program="iinfo")
command += info_command ("--echo \"info from oiiotool:\" --hash --stats --dumpdata src/tiny-az.exr", info_program="oiiotool")

# Get iinfo coverage of a deep file
# command += oiiotool ("-pattern constant:color=1e38,0 4x4 2 --chnames Z,A"
#                      " --point:color=10.0,1.0 2,2 --deepen -o tinydeep.exr")
command += info_command ("-v --hash --stats src/tinydeep.exr", info_program="iinfo")
command += info_command ("--echo \"info from oiiotool:\" --hash --stats --dumpdata src/tinydeep.exr", info_program="oiiotool")

# Dump of a flat integer file
command += oiiotool ("-pattern constant:color=0.25,0.5,0.75 2x2 3 -d uint8 -o tmp.tif")
command += oiiotool ("-echo \"uint8 file\" --hash --stats --dumpdata tmp.tif")

# Dump data in C style
command += oiiotool ("-echo \"int16 file, C format dump\" --dumpdata:C=foo tmp.tif")

# info in xml
command += info_command ("--info:format=xml tmp.tif", safematch=True)

# Info for subimages and mips
command += info_command ("--stats src/subimage.tif", info_program="iinfo")
command += info_command ("--stats src/mip.tif", info_program="iinfo")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Test the filters

import OpenImageIO as oiio

filters = oiio.get_string_attribute("filter_list").split(";")
print ("all filters: ", filters)
i = 0
outputs = [ ]

delta = oiio.ImageBuf(oiio.ImageSpec(16, 16, 1, "float"))
oiio.ImageBufAlgo.render_point(delta, 8, 8)

for f in filters:
    buf = oiio.ImageBufAlgo.resize(delta, f, roi=oiio.ROI(0, 80, 0, 80, 0, 1))
    # Make a marker different for each filter so they dont compare against
    # each other
    oiio.ImageBufAlgo.render_point(buf, i, 0)
    i += 1
    buf.write("{}.exr".format(f), "half")
    outputs += [ "{}.exr".format(f) ]

outputs += [ "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


imagedir = "ref/"
files = [ "norle-8.sgi", "rle-8.sgi", "norle-16.sgi", "rle-16.sgi" ]
for f in files:
    command = command + rw_command (imagedir, f)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


import OpenImageIO as oiio
import os

redirect = " >> out.txt 2>> out.err.txt"

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/targa"

files = [ "CBW8.TGA", "CCM8.TGA", "CTC16.TGA", "CTC24.TGA", "CTC32.TGA",
          "UBW8.TGA", "UCM8.TGA", "UTC16.TGA", "UTC24.TGA", "UTC32.TGA",
          "round_grill.tga" ]


# Test ability to extract thumbnails
outputs = [ ]
for f in files:
    fin = imagedir + "/" + f
    buf = oiio.ImageBuf(fin)
    if buf.has_thumbnail :
        thumbname = f + ".tif"
        command += run_app(pythonbin + " src/extractthumb.py " + fin + " " + thumbname)
        outputs += [ thumbname ]

outputs += [ 'out.txt' ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


from __future__ import absolute_import
import shutil

# Make a copy called "misnamed.exr" that's actually a TIFF file
shutil.copyfile ("../common/grid.tif", "misnamed.exr")

# Now see if it is read correctly
command = info_command ("misnamed.exr")



#!/usr/bin/env python 

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Copy the grid to both a tiled and scanline version
imagedir = OIIO_TESTSUITE_IMAGEDIR
command += oiio_app("iconvert") + "../common/grid.tif --scanline scanline.tif > out.txt ;" 
command += oiio_app("iconvert") + "../common/grid.tif --tile 64 64 tiled.tif > out.txt ;" 

# Run the script 
command += pythonbin + " src/test_imageoutput.py >> out.txt ;"

# compare the outputs -- these are custom because they compare to grid.tif
files = [ "grid-image.tif", "grid-scanline.tif", "grid-scanlines.tif",
          "grid-timage.tif", "grid-tile.tif", "grid-tiles.tif", "grid-half.exr" ]
for f in files :
    command += (oiio_app("idiff") + " -fail 0.001 -warn 0.001 "
                + f + " ../common/grid.tif >> out.txt ;")

outputs = [ "multipart.exr", "out.txt" ]




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

redirect = " >> out.txt 2>&1"

files = [ "ginsu_a_nc10.rla", "ginsu_a_ncf.rla", "ginsu_rgba_nc8.rla",
          "ginsu_rgb_nc16.rla", "imgmake_rgba_nc10.rla", "ginsu_a_nc16.rla",
          "ginsu_rgba_nc10.rla", "ginsu_rgba_ncf.rla", "ginsu_rgb_nc8.rla",
          "imgmake_rgba_nc16.rla", "ginsu_a_nc8.rla", "ginsu_rgba_nc16.rla",
          "ginsu_rgb_nc10.rla", "ginsu_rgb_ncf.rla", "imgmake_rgba_nc8.rla" ]
for f in files:
    command += rw_command (OIIO_TESTSUITE_IMAGEDIR, f)

# Regression test to ensure crops work
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR +
                     "/ginsu_rgb_nc8.rla -crop 100x100+100+100 -o rlacrop.rla")
# Test corrupted files
command += oiiotool(OIIO_TESTSUITE_IMAGEDIR + "/crash1.rla -o crash1.exr", failureok = True)
command += oiiotool(OIIO_TESTSUITE_IMAGEDIR + "/crash2.rla -o crash2.exr", failureok = True)
command += oiiotool("src/crash-1629.rla -o crash3.exr", failureok = True)
command += oiiotool("src/crash-3951.rla -o crash4.exr", failureok = True)

outputs = [ "rlacrop.rla", 'out.txt' ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

redirect = ' >> out.txt 2>&1 '

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/pnm"

for f in [ "bw-ascii.pbm", "bw-binary.pbm",
           "grey-ascii.pgm", "grey-binary.pgm",
           "rgb-ascii.ppm", "rgb-binary.ppm" ] :
    command += rw_command ("src", f)

# We can't yet write PFM files, so just get the hashes and call it a day
files = [ "test-1.pfm", "test-2.pfm", "test-3.pfm" ]
for f in files:
    command += info_command (imagedir + "/" + f,
                             safematch=True, hash=True)

# Damaged files
files = [ "src/bad-4553.pgm" ]
for f in files:
    command += info_command (f, extraargs="--oiioattrib try_all_readers 0 --printstats", failureok=True)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Test reading and writing of files with "rational" metadata


# Round trip of a file known to have some rational values
command += rw_command ("src", "test.exr")


# Try setting rational metadata as "a/b" on the oiiotool command line
command += oiiotool ("--create 64x64 3 --attrib:type=rational onehalf 50/100 -o rat2.exr")
command += info_command ("rat2.exr", safematch=True)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command = (oiio_app("testtex") + " -res 256 256 "
           + "-texoptions max_mip_res=128 "
           + OIIO_TESTSUITE_IMAGEDIR + "/miplevels.tx"
           + " -d uint8 -o out.tif ;\n")

outputs = [ "out.tif", "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


failureok = 1
redirect = ' >> out.txt 2>&1 '

# This file has a corrupted Exif block in the metadata. It used to
# crash on some platforms, on others would be caught by address sanitizer.
# Fixed by #1635. This test serves to guard against regressions.
command += info_command ("src/corrupt-exif.jpg", safematch=True)

# This file has a corrupted Exif block that makes it look like one item has a
# nonsensical length, that before being fixed, caused a buffer overrun.
command += info_command ("src/corrupt-exif-1626.jpg", safematch=True)




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# save the error output
redirect = " >> out.txt 2>&1 "
failureok = 1

files = [ "g01bg.bmp", "g01bw.bmp", "g01p1.bmp", "g01wb.bmp",
          "g04.bmp", "g04p4.bmp", "g04rle.bmp",
          "g08.bmp", "g08os2.bmp", "g08p64.bmp", "g08p256.bmp",
          "g08pi64.bmp", "g08pi256.bmp",
          "g08res11.bmp", "g08res21.bmp", "g08res22.bmp",
          "g08s0.bmp", "g08w124.bmp", "g08w125.bmp", "g08w126.bmp",
          "g08rle.bmp", "g08offs.bmp",
          "g24.bmp", "g32bf.bmp", "g32def.bmp",
          "g16bf555.bmp", "g16bf565.bmp", "g16def555.bmp" ]
for f in files :
    command += rw_command (OIIO_TESTSUITE_IMAGEDIR, f)

# Test BMR version 5
command += rw_command ("src", "g01bg2-v5.bmp")

# Regression test for old OS2 flavor of BMP.
# See https://github.com/AcademySoftwareFoundation/OpenImageIO/issues/2898
command += rw_command ("src", "PRINTER.BMP")

# Test BMP of the 56-byte DIB header variety
command += rw_command ("../oiio-images/bmp", "gracehopper.bmp")

# See if we handle these corrupt files with useful error messages
command += info_command ("src/decodecolormap-corrupt.bmp")
command += info_command ("src/bad-y.bmp")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# ../openexr-images/Chromaticities:
# README         Rec709.exr     Rec709_YC.exr  XYZ.exr        XYZ_YC.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Chromaticities"
files = [
    "Rec709_YC.exr", "XYZ_YC.exr"
]
for f in files:
    command += rw_command (imagedir, f)

# ../openexr-images/LuminanceChroma:
# CrissyField.exr  Garden.exr       StarField.exr
# Flowers.exr      MtTamNorth.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/LuminanceChroma"
# Request a lossless compression method for the first two images. Otherwise,
# the b44 compression from the input image carries over to the output image and
# causes pretty large compression artefacts.
command += rw_command (imagedir, "CrissyField.exr", extraargs="--compression zip")
command += rw_command (imagedir, "Flowers.exr", extraargs="--compression zip")
command += rw_command (imagedir, "MtTamNorth.exr")
command += rw_command (imagedir, "StarField.exr")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command += oiiotool ('-v -info -stats "foo.null?RES=640x480&CHANNELS=3&TYPE=uint8&PIXEL=0.25,0.5,1"')



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


shutil.copyfile ("../common/textures/grid.tx", "grid.tx")

command += pythonbin + " src/test_imageinput.py > out.txt"




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Test that appending channels fixes duplicate channel names


# Test 1: Make two images, both with R,G,B channel names, so duplicated.
# When mashing them together, they should end up with channels
# R, G, B, channel3, channel4, channel5.
command += oiiotool ("--create 64x64 3 -d uint8 -o a.exr")
command += oiiotool ("--create 64x64 3 -d uint8 -o b.exr")
command += oiiotool ("a.exr b.exr -chappend -o out.exr")
command += info_command ("out.exr", safematch=True)


# Test 2: Start with a multi-image file with different subimage names,
# then split subimages and append channels (convert multi-image file to
# single image / many-channel). The new channel names should be
# de-duplicated by using the subimage names. The resulting image should
# have channels R, G, B, Bimg.R, Bimg.G, Bimg.B.
command += oiiotool ("a.exr --attrib oiio:subimagename Aimg " +
                     "b.exr --attrib oiio:subimagename Bimg " +
                     "--siappend -o multi.exr")
command += oiiotool ("multi.exr -sisplit --chappend -o out2.exr")
command += info_command ("out2.exr", safematch=True)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Allow some LSB slop -- necessary because of the alpha disassociation
# combined with implied sRGB conversion.
failthresh = 0.02
failpercent = 0.02
redirect = ' >> out.txt 2>&1 '
failureok = True

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/jpeg2000/broken"
files = [ "issue_3427.jp2" ]
for f in files:
    command += rw_command (imagedir, f, printinfo=False)




#!/usr/bin/python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Format the output from various oiio command line "$tool --help" invocations,
# and munge such that txt2man generates a simple man page with not-too-horrible
# formatting.

from __future__ import print_function
from __future__ import absolute_import
import sys

lines = [l.rstrip().replace('\t', ' '*8) for l in sys.stdin.readlines()]

print('NAME')
print(lines[0])
print()

print('SYNOPSIS')
for i,line in enumerate(lines[2:]):
    if line.lstrip().startswith('-') or line.lstrip().startswith('Options'):
        optStart = i+2
        break
    print(line)

print('''DESCRIPTION
This program is part of the OpenImageIO (http://www.openimageio.org) tool suite.
Detailed documentation is available in pdf format with the OpenImageIO
distribution.
''')

print('OPTIONS')
for line in lines[optStart:]:
    if not line.startswith(' '):
        print()
        print(line)
    elif not line.lstrip().startswith('-'):
        print(line.lstrip())
    else:
        print(line)
print()



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# This test just views the "miplevels" texture straight on, but it uses
# -widthramp to smoothly blend between mipmap levels from left to right
# (wanting the 256^2 level at the left and the 64^2 level at the right).
# Using MIPmode StochasticAniso and pseudo-random variate, this tests that
# we are blending between the levels correctly.


command = testtex_command (OIIO_TESTSUITE_IMAGEDIR + "/miplevels.tx",
                           " -nowarp -res 256 256 -stochastic 1 -widthramp 4 -d uint8 -o out.tif")
outputs = [ "out.tif" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

import os, sys

####################################################################
# This test exercises oiiotool functionality that is mostly about
# copying pixels from one image to another.
####################################################################

# Capture error output
redirect = " >> out.txt 2>&1 "

# Create some test images we need
command += oiiotool("../common/tahoe-tiny.tif --compression pxr24 -o ref/compressed-pxr24.exr")
command += oiiotool("../common/tahoe-tiny.tif --compression b44 -o ref/compressed-b44.exr")
command += oiiotool("../common/tahoe-tiny.tif --compression b44a -o ref/compressed-b44a.exr")
command += oiiotool("../common/tahoe-tiny.tif --compression dwaa -o ref/compressed-dwaa.exr")
command += oiiotool("../common/tahoe-tiny.tif --compression dwab -o ref/compressed-dwab.exr")

# Run the recompression test script 
command += pythonbin + " src/test_recompression.py;"

# Outputs to check against references
outputs = [
    "compressed-pxr24.exr",
    "compressed-b44.exr",
    "compressed-b44a.exr",
    "compressed-dwaa.exr",
    "compressed-dwab.exr",
]

# OpenEXRInputCore is not supported yet. TODO: update this once it's implemented.
if os.environ.get("OPENIMAGEIO_OPTIONS") == "openexr:core=1":
    outputs = []

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import
import os
import numpy

import OpenImageIO as oiio


checker = os.path.abspath("../common/textures/checker.tx")
texture_sys = oiio.TextureSystem()
texture_opt = oiio.TextureOpt()

texture_opt.swrap = oiio.Wrap.Periodic
texture_opt.twrap = oiio.Wrap.Periodic


# Test getattribute


print ("checker middle, top mip, channels: 1 =", texture_sys.texture(checker, texture_opt, 0.5, 0.5, 0, 0, 0, 0, 1))
print ("checker middle, top mip, channels: 2 =", texture_sys.texture(checker, texture_opt, 0.5, 0.5, 0, 0, 0, 0, 2))
print ("checker middle, top mip, channels: 3 =", texture_sys.texture(checker, texture_opt, 0.5, 0.5, 0, 0, 0, 0, 3))
print ("")

print ("checker middle, mip tail, channels: 1 =", texture_sys.texture(checker, texture_opt, 0.5, 0.5, 1/1024.0, 1/1024.0, 1/1024.0, 1/1024.0, 1))
print ("")

texture_opt.missingcolor = (1.0, 2.0, 3.0, 4.0)
print ("missingcolor channels: 1 =", texture_sys.texture("", texture_opt, 0, 0, 0, 0, 0, 0, 1))
print ("missingcolor channels: 2 =", texture_sys.texture("", texture_opt, 0, 0, 0, 0, 0, 0, 2))
print ("missingcolor channels: 3 =", texture_sys.texture("", texture_opt, 0, 0, 0, 0, 0, 0, 3))
print ("missingcolor channels: 4 =", texture_sys.texture("", texture_opt, 0, 0, 0, 0, 0, 0, 4))
print ("")

texture_opt.missingcolor = None
print ("default-missingcolor =", texture_sys.texture("", texture_opt, 0, 0, 0, 0, 0, 0, 4))
print ("")

# Test if fetching the textures biggest mip via the texture system, results in the same image
texture_opt.interpmode = oiio.InterpMode.Bilinear
checker_buf = oiio.ImageBuf(checker)
render_buf = oiio.ImageBuf(checker_buf.spec())

image_pixels = [
    texture_sys.texture(checker, texture_opt, (x+0.5)/512.0, (y+0.5)/512.0, 0, 0, 0, 0, 3)
    for y in range(512)
    for x in range(512)
]
render_buf.set_pixels(render_buf.roi, numpy.array(image_pixels))
diff = oiio.ImageBufAlgo.compare(checker_buf, render_buf, 0, 0)

print("top mip pixel differences when streaming =", diff.nfail)

print ("")

# Test udim
udname = 'file.<UDIM>.tx'
(utiles, vtiles, tilenames) = texture_sys.inventory_udim(udname)
print("udim {} -> {}x{} {}".format(udname, utiles, vtiles, tilenames))


# Test getattribute() and getattributetype()
print ("getattributetype stat:image_size", texture_sys.getattributetype("stat:image_size"))
print ("getattributetype total_files", texture_sys.getattributetype("total_files"))
print ("getattributetype max_memory_MB", texture_sys.getattributetype("max_memory_MB"))
print ("getattributetype worldtocommon", texture_sys.getattributetype("worldtocommon"))

# Test getattribute(name) with the type inferred from the attribute
print ("untyped getattribute stat:image_size", texture_sys.getattribute("stat:image_size"))
print ("untyped getattribute total_files", texture_sys.getattribute("total_files"))
print ("untyped getattribute max_memory_MB", texture_sys.getattribute("max_memory_MB"))
print ("untyped getattribute worldtocommon", texture_sys.getattribute("worldtocommon"))

print("Done.")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


if platform.system() == 'Windows' :
    prefix = ".\\build\\Release\\"
else :
    prefix = "./build/"

# Prep:
command += run_app("cmake -E copy " + test_source_dir + "/../common/grid-small.exr grid.exr")
command += run_app("cmake -E copy " + test_source_dir + "/../common/tahoe-small.tif tahoe.tif")

# Build
command += run_app("cmake -S " + test_source_dir + " -B build -DCMAKE_BUILD_TYPE=Release >> build.txt 2>&1", silent=True)
command += run_app("cmake --build build --config Release >> build.txt 2>&1", silent=True)

# Run the examples for each chapter
for chapter in [ "imageioapi", "imageoutput", "imageinput", "writingplugins",
                 "imagecache", "texturesys", "imagebuf", "imagebufalgo" ] :
    command += run_app(prefix + "docs-examples-" + chapter)

# hashes merely check that the images don't change, but saves us the space
# of checking in a full copy of the image if it's not needed.
hashes = [
    # Outputs from the ImageBufAlgo chapter:
    "zero1.exr",
    "zero2.exr",
    "zero3.exr",
    "zero4.exr",
    "fill.exr",
    "checker.exr",
    "noise1.exr",
    "noise2.exr",
    "noise3.exr",
    "noise4.exr",
    "blue-noise.exr",
    "point.exr",
    "lines.exr",
    "box.exr",
    "text1.exr",
    "text2.exr",
    "cshift.exr",
    "texture.exr"
]
for file in hashes :
    command += info_command(file, verbose=False)

# outputs should contain all the images that need to be checked directly
# and need the images checked into the ref directory.
outputs = [
    # Outputs from the ImageOutput chapter:
    "simple.tif", "scanlines.tif",
    # Outputs from the ImageInput chapter:

    # ... etc ... other chapters ...

    # Last, we have the out.txt that captures console output of the test
    # programs.
    "out.txt"
    ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


redirect = ' >> out.txt 2>&1 '

command += oiiotool ("-pattern fill:topleft=1,0,0:topright=0,1,0:bottomleft=0,0,1:bottomright=1,1,1 60x40 3 -o ramp.exr")
command += oiiotool ("-pattern fill:topleft=1,0,0:topright=0,1,0:bottomleft=0,0,1:bottomright=1,1,1 20x10 3 -o rampsmall.exr")

# Simplify by treating everything as sRGB already, so the tests don't include
# any uncertainty about color space conversion.
command += oiiotool ("-echo 24bit rampsmall.exr -iscolorspace srgb -attrib term:method 24bit -attrib term:fit 0 -attrib term:filename 24bit.out -o 24bit.term")
command += oiiotool ("-echo 24bit-space rampsmall.exr -iscolorspace srgb -attrib term:method 24bit-space -attrib term:fit 0 -attrib term:filename 24bit-space.out -o 24bit-space.term")
command += oiiotool ("-echo dither rampsmall.exr -iscolorspace srgb -attrib term:method dither -attrib term:fit 0 -attrib term:filename dither.out -o dither.term")
command += oiiotool ("-echo iterm2 ramp.exr -iscolorspace srgb -attrib term:method iterm2 -attrib term:fit 0 -attrib term:filename iterm2.out -o iterm2.term")

command += oiiotool ("-echo done")

outputs = [ "24bit.out", "24bit-space.out", "dither.out",
            "iterm2.out",
            "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import
import OpenImageIO as oiio


# Test that every expected enum value of BASETYPE exists
def basetype_enum_test():
    try:
        oiio.UNKNOWN
        oiio.NONE
        oiio.UCHAR
        oiio.UINT8
        oiio.CHAR
        oiio.INT8
        oiio.USHORT
        oiio.UINT16
        oiio.SHORT
        oiio.INT16
        oiio.UINT
        oiio.UINT32
        oiio.INT
        oiio.INT32
        oiio.ULONGLONG
        oiio.UINT64
        oiio.LONGLONG
        oiio.INT64
        oiio.HALF
        oiio.FLOAT
        oiio.DOUBLE
        oiio.STRING
        oiio.PTR
        oiio.LASTBASE
        print ("Passed BASETYPE")
    except:
        print ("Failed BASETYPE")


# Test that every expected enum value of AGGREGATE exists
def aggregate_enum_test():
    try:
        oiio.NOSEMANTICS
        oiio.SCALAR
        oiio.VEC2
        oiio.VEC3
        oiio.VEC4
        oiio.MATRIX33
        oiio.MATRIX44
        print ("Passed AGGREGATE")
    except:
        print ("Failed AGGREGATE")


# Test that every expected enum value of VECSEMANTICS exists
def vecsemantics_enum_test():
    try:
        oiio.NOXFORM
        oiio.COLOR
        oiio.POINT
        oiio.VECTOR
        oiio.NORMAL
        oiio.TIMECODE
        oiio.KEYCODE
        oiio.RATIONAL
        oiio.BOX
        print ("Passed VECSEMANTICS")
    except:
        print ("Failed VECSEMANTICS")

# print the details of a type t
def breakdown_test(t, name="", verbose=True):
    print ("type '%s'" % name)
    print ("    c_str \"" + t.c_str() + "\"")
    if verbose:
        print ("    basetype", t.basetype)
        print ("    aggregate", t.aggregate)
        print ("    vecsemantics", t.vecsemantics)
        print ("    arraylen", t.arraylen)
        print ("    str(t) = \"" + str(t) + "\"")
        print ("    size =", t.size())
        print ("    elementtype =", t.elementtype())
        print ("    numelements =", t.numelements())
        print ("    basevalues =", t.basevalues())
        print ("    elementsize =", t.elementsize())
        print ("    basesize =", t.basesize())


######################################################################
# main test starts here

try:
    # Test that all the enum values exist
    basetype_enum_test()
    aggregate_enum_test()
    vecsemantics_enum_test()
    print ("")

    # Exercise the different constructors, make sure they create the
    # correct TypeDesc (also exercises the individual fields, c_str(),
    # conversion to string).
    breakdown_test (oiio.TypeDesc(), "(default)")
    breakdown_test (oiio.TypeDesc(oiio.UINT8), "UINT8")
    breakdown_test (oiio.TypeDesc(oiio.HALF, oiio.VEC3, oiio.COLOR),
                    "HALF, VEC3, COLOR")
    breakdown_test (oiio.TypeDesc(oiio.FLOAT, oiio.SCALAR, oiio.NOXFORM, 6),
                    "FLOAT, SCALAR, NOXFORM, array of 6")
    breakdown_test (oiio.TypeDesc(oiio.FLOAT, oiio.VEC3, oiio.POINT, 2),
                    "FLOAT, VEC3, POINT, array of 2")
    breakdown_test (oiio.TypeDesc(oiio.INT, oiio.VEC2, oiio.BOX, 2),
                    "INT, VEC2, BOX, array of 2")
    breakdown_test (oiio.TypeDesc(oiio.FLOAT, oiio.VEC3, oiio.BOX, 2),
                    "FLOAT, VEC3, BOX, array of 2")
    print ("")

    # Test construction from a string descriptor
    breakdown_test (oiio.TypeDesc("float[2]"), "float[2]")
    breakdown_test (oiio.TypeDesc("normal"), "normal")
    breakdown_test (oiio.TypeDesc("uint16"), "uint16")
    breakdown_test (oiio.TypeDesc("box3"), "box3")
    print ("")

    # Test equality, inequality, and equivalent
    t_uint8 = oiio.TypeDesc("uint8")
    t_uint16 = oiio.TypeDesc("uint16")
    t_uint8_b = oiio.TypeDesc("uint8")
    print ("uint8 == uint8?", (t_uint8 == t_uint8))
    print ("uint8 == uint8?", (t_uint8 == t_uint8_b))
    print ("uint8 == uint16", (t_uint8 == t_uint16))
    print ("uint8 != uint8?", (t_uint8 != t_uint8))
    print ("uint8 != uint8?", (t_uint8 != t_uint8_b))
    print ("uint8 != uint16", (t_uint8 != t_uint16))
    print ("vector == color", (oiio.TypeDesc("vector") == oiio.TypeDesc("color")))
    print ("vector.equivalent(color)", oiio.TypeDesc("vector").equivalent(oiio.TypeDesc("color")))
    print ("equivalent(vector,color)", oiio.TypeDesc.equivalent(oiio.TypeDesc("vector"), oiio.TypeDesc("color")))
    print ("vector.equivalent(float)", oiio.TypeDesc("vector").equivalent(oiio.TypeDesc("float")))
    print ("equivalent(vector,float)", oiio.TypeDesc.equivalent(oiio.TypeDesc("vector"), oiio.TypeDesc("float")))
    print ("")

    # DEPRECATED(1.8): Test the static data member types of pre-constructed types
    breakdown_test (oiio.TypeDesc.TypeFloat,    "TypeFloat",    verbose=False)
    breakdown_test (oiio.TypeDesc.TypeColor,    "TypeColor",    verbose=False)
    breakdown_test (oiio.TypeDesc.TypeString,   "TypeString",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeInt,      "TypeInt",      verbose=False)
    breakdown_test (oiio.TypeDesc.TypePoint,    "TypePoint",    verbose=False)
    breakdown_test (oiio.TypeDesc.TypeVector,   "TypeVector",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeNormal,   "TypeNormal",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeMatrix,   "TypeMatrix",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeMatrix33, "TypeMatrix33", verbose=False)
    breakdown_test (oiio.TypeDesc.TypeMatrix44, "TypeMatrix44", verbose=False)
    breakdown_test (oiio.TypeDesc.TypeTimeCode, "TypeTimeCode", verbose=False)
    breakdown_test (oiio.TypeDesc.TypeKeyCode,  "TypeKeyCode",  verbose=False)
    breakdown_test (oiio.TypeDesc.TypeRational, "TypeRational", verbose=False)
    breakdown_test (oiio.TypeDesc.TypeFloat2,   "TypeFloat2",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeVector2,  "TypeVector2",  verbose=False)
    breakdown_test (oiio.TypeDesc.TypeFloat4,   "TypeFloat4",   verbose=False)
    breakdown_test (oiio.TypeDesc.TypeVector4,  "TypeVector4",  verbose=False)
    breakdown_test (oiio.TypeDesc.TypeVector2i, "TypeVector2i", verbose=False)
    breakdown_test (oiio.TypeDesc.TypeHalf,     "TypeHalf",     verbose=False)
    print ("")

    # Test the pre-constructed types
    breakdown_test (oiio.TypeFloat,    "TypeFloat",    verbose=False)
    breakdown_test (oiio.TypeColor,    "TypeColor",    verbose=False)
    breakdown_test (oiio.TypeString,   "TypeString",   verbose=False)
    breakdown_test (oiio.TypeInt,      "TypeInt",      verbose=False)
    breakdown_test (oiio.TypeUInt,     "TypeUInt",     verbose=False)
    breakdown_test (oiio.TypeInt64,    "TypeInt64",    verbose=False)
    breakdown_test (oiio.TypeUInt64,   "TypeUInt64",   verbose=False)
    breakdown_test (oiio.TypeInt32,    "TypeInt32",    verbose=False)
    breakdown_test (oiio.TypeUInt32,   "TypeUInt32",   verbose=False)
    breakdown_test (oiio.TypeInt16,    "TypeInt16",    verbose=False)
    breakdown_test (oiio.TypeUInt16,   "TypeUInt16",   verbose=False)
    breakdown_test (oiio.TypeInt8,     "TypeInt8",     verbose=False)
    breakdown_test (oiio.TypeUInt8,    "TypeUInt8",    verbose=False)
    breakdown_test (oiio.TypePoint,    "TypePoint",    verbose=False)
    breakdown_test (oiio.TypeVector,   "TypeVector",   verbose=False)
    breakdown_test (oiio.TypeNormal,   "TypeNormal",   verbose=False)
    breakdown_test (oiio.TypeMatrix,   "TypeMatrix",   verbose=False)
    breakdown_test (oiio.TypeMatrix33, "TypeMatrix33", verbose=False)
    breakdown_test (oiio.TypeMatrix44, "TypeMatrix44", verbose=False)
    breakdown_test (oiio.TypeTimeCode, "TypeTimeCode", verbose=False)
    breakdown_test (oiio.TypeKeyCode,  "TypeKeyCode",  verbose=False)
    breakdown_test (oiio.TypeFloat2,   "TypeFloat2",   verbose=False)
    breakdown_test (oiio.TypeVector2,  "TypeVector2",  verbose=False)
    breakdown_test (oiio.TypeFloat4,   "TypeFloat4",   verbose=False)
    breakdown_test (oiio.TypeVector4,  "TypeVector4",  verbose=False)
    breakdown_test (oiio.TypeVector2i, "TypeVector2i", verbose=False)
    breakdown_test (oiio.TypeHalf,     "TypeHalf",     verbose=False)
    breakdown_test (oiio.TypeRational, "TypeRational", verbose=False)
    breakdown_test (oiio.TypeUInt,     "TypeUInt",     verbose=False)
    print ("")

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

import os, sys, platform

# This works around the python 3.8 change to stop loading DLLs from PATH on Windows.
# We reproduce the old behaviour by manually tokenizing PATH, checking that the directories exist and are not ".",
# then add them to the DLL load path.
# This behviour can be disabled by setting the environment variable "OIIO_LOAD_DLLS_FROM_PATH" to "0"
if sys.version_info >= (3, 8) and platform.system() == "Windows" and os.getenv("OIIO_LOAD_DLLS_FROM_PATH", "1") == "1":
    for path in os.getenv("PATH", "").split(os.pathsep):
        if os.path.exists(path) and path != ".":
            os.add_dll_directory(path)

from .OpenImageIO import *




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

import os, sys

####################################################################
# Verify decreasingY line order generates same image as increasingY (default).
####################################################################

# Capture error output
redirect = " >> out.txt 2>&1 "

# Create reference images stored in increasingY order (default)
# Resizing to a large image size to ensure scanline chunking logic is triggered.
command += oiiotool("../common/tahoe-tiny.tif --resize 4080x3072 -o ref/decreasingY-resize.exr")
command += info_command("ref/decreasingY-resize.exr")
command += oiiotool("ref/decreasingY-resize.exr -o ref/decreasingY-copy.exr")
command += info_command("ref/decreasingY-copy.exr")

# Create an image in decreasing order via resizing (Tests ImageOutput::write_image() logic)
command += oiiotool("../common/tahoe-tiny.tif --resize 4080x3072 --attrib openexr:lineOrder decreasingY -o decreasingY-resize.exr")
command += info_command("decreasingY-resize.exr")

# Create an image in decreasing order via copying a reference image. (Tests ImageBuf::write() logic)
command += oiiotool("ref/decreasingY-resize.exr --attrib openexr:lineOrder decreasingY -o decreasingY-copy.exr")
command += info_command("decreasingY-copy.exr")

# Outputs to check against references.
# This makes sure the images look the same since the line order is a storage detail and should not
# change how the image actually looks. These comparisons help verify chunk order and scanlines are
# processed properly.
outputs = [
    "decreasingY-resize.exr",
    "decreasingY-copy.exr",
]


#print "Running this command:\n" + command + "\n"


#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

filename = (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg")
command += info_command (filename)
command += oiiotool (filename + " -o ./tahoe-gps.jpg")
command += info_command ("tahoe-gps.jpg", safematch=True)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


imagedir = "../common"

compressions = [
    "none",
    "rle",
    "zips",
    "zip",
    "piz",
    "pxr24",
    "b44",
    "b44a",
    "dwaa",
    "dwab",
]

anymatch = True
outputs = []
for c in compressions:
    outname = "out-" + c + ".exr"
    command += oiiotool("../common/tahoe-tiny.tif --compression " + c +
                        " -o " + outname)
    command += oiiotool(outname + " --echo \"" + outname + " compression "
                        + "{TOP.compression}\"")
    outputs += [ outname ]

outputs += [ "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

command = rw_command (OIIO_TESTSUITE_IMAGEDIR, "oiio.ico")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Create some test images we need
command += oiiotool ("--create 320x240 3 -d uint8 -o black.tif")
command += oiiotool ("--pattern constant:color=0.5,0.5,0.5 128x128 3 -d half -o grey128.exr")
command += oiiotool ("--pattern constant:color=0.5,0.5,0.5 64x64 3 -d half -o grey64.exr")
command += oiiotool ("--create 256x256 3 --fill:color=1,.5,.5 256x256 --fill:color=0,1,0 80x80+100+100 -d uint8 -o filled.tif")


# test --autotrim
command += oiiotool ("black.tif --fill:color=0,1,0 80x80+100+100 --autotrim -d uint8 -o autotrim.tif")

# test --colorcount  (using the results of the --fill test)
command += oiiotool ("filled.tif --colorcount:eps=.1,.1,.1 0,0,0:1,.5,.5:0,1,0")

# test --rangecheck  (using the results of the --fill test)
command += oiiotool ("filled.tif --rangecheck 0,0,0 1,0.9,1")

# test --rangecompress & --rangeexpand
command += oiiotool ("../common/tahoe-small.tif --rangecompress -d uint8 -o rangecompress.tif")
command += oiiotool ("rangecompress.tif --rangeexpand -d uint8 -o rangeexpand.tif")
command += oiiotool ("../common/tahoe-small.tif --rangecompress:luma=1 -d uint8 -o rangecompress-luma.tif")
command += oiiotool ("rangecompress-luma.tif --rangeexpand:luma=1 -d uint8 -o rangeexpand-luma.tif")

# Test --add
command += oiiotool ("--pattern constant:color=.1,.2,.3 64x64+0+0 3 "
            + " --pattern constant:color=.1,.1,.1 64x64+20+20 3 "
            + " --add -d half -o add.exr")
# Test --addc val (add to all channels the same scalar)
command += oiiotool ("grey128.exr --addc 0.25 -o cadd1.exr")
# Test --addc val,val,val... (add per-channel scalars)
command += oiiotool ("grey128.exr --addc 0,0.25,-0.25 -o cadd2.exr")

# Test --sub, subc
command += oiiotool ("--pattern constant:color=.1,.2,.3 64x64+0+0 3 "
            + " --pattern constant:color=.1,.1,.1 64x64+20+20 3 "
            + " --sub -d half -o sub.exr")
command += oiiotool ("--pattern constant:color=.1,.2,.3 64x64+0+0 3 "
            + " --subc 0.1,0.1,0.1 -d half -o subc.exr")

# test --mul of images
command += oiiotool ("grey64.exr -pattern constant:color=1.5,1,0.5 64x64 3 --mul -o mul.exr")
# Test --mulc val (multiply all channels by the same scalar)
command += oiiotool ("grey128.exr --mulc 1.5 -o cmul1.exr")
# Test --mulc val,val,val... (multiply per-channel scalars)
command += oiiotool ("grey128.exr --mulc 1.5,1,0.5 -o cmul2.exr")

# Test --divc val (divide all channels by the same scalar)
command += oiiotool ("grey64.exr --divc 2.0 -d half -o divc1.exr")
# Test --divc val,val,val... (divide per-channel scalars)
command += oiiotool ("grey64.exr --divc 2.0,1,0.5 -d half -o divc2.exr")
# Test --div of images
command += oiiotool ("grey64.exr --pattern constant:color=2.0,1,0.5 64x64 3 "
                   + "--div -d half -o div.exr")

# test --mad of images
command += oiiotool ("grey64.exr -pattern constant:color=1.5,1,0.5 64x64 3 "
                   + "-pattern constant:color=.1,.1,.1 64x64 3 --mad -o mad.exr")

# test --invert
command += oiiotool ("../common/tahoe-small.tif --invert -o invert.tif")

# Test --powc val (raise all channels by the same power)
command += oiiotool ("grey128.exr --powc 2 -o cpow1.exr")
# Test --powc val,val,val... (per-channel powers)
command += oiiotool ("grey128.exr --powc 2,2,1 -o cpow2.exr")

# Test --normalize
command += oiiotool ("src/norm.exr --normalize -o normalize.exr " +
                     "src/norm.exr --normalize:scale=0.5 -o normalize_scale.exr " +
                     "src/normoffset.exr --normalize:incenter=0.5 -o normalize_offsetin.exr " +
                     "src/norm.exr --normalize:outcenter=0.5:scale=0.5 -o normalize_offsetscaleout.exr " +
                     "src/normoffset.exr --normalize:incenter=0.5:outcenter=0.5:scale=0.5 -o normalize_offsetscale.exr ")


# Test --abs, --absdiff, --absdiffc
# First, make a test image that's 0.5 on the left, -0.5 on the right
command += oiiotool ("-pattern constant:color=-0.25,-0.25,-0.25 64x128 3 "
                   + "-pattern constant:color=0.5,0.5,0.5 64x128 3 "
                   + "-mosaic 2x1 -d half -o negpos.exr")
command += oiiotool ("negpos.exr -abs -o abs.exr")
command += oiiotool ("negpos.exr -pattern constant:color=0.2,0.2,0.2 128x128 3 "
                   + "-absdiff -d half -o absdiff.exr")
command += oiiotool ("negpos.exr -absdiffc 0.2,0.2,0.2 -d half -o absdiffc.exr")

# test --chsum
command += oiiotool ("../common/tahoe-small.tif --chsum:weight=.2126,.7152,.0722 "
            + "-d uint8 -o chsum.tif")

# test --trim
command += oiiotool ("--create 320x240 3 -fill:color=.1,.5,.1 120x80+50+70 "
                     + " -rotate 30 -trim -origin +0+0 -fullpixels -d uint8 -o trim.tif")

# test --trim, tricky case of multiple subimages
command += oiiotool (  "-a --create 320x240 3 -fill:color=.1,.5,.1 120x80+50+70 -rotate 30 "
                     + "--create 320x240 3 -fill:color=.5,.5,.1 100x10+70+70 -rotate 140 "
                     + "--siappend -trim -origin +0+0 -fullpixels -d uint8 -o trimsubimages.tif")

# test hole filling
command += oiiotool ("ref/hole.tif --fillholes -o tahoe-filled.tif")
# test hole filling for a cropped image
command += oiiotool ("-pattern checker 64x64+32+32 3 -ch R,G,B,A=1.0 -fullsize 128x128+0+0 --croptofull -fillholes -d uint8 -o growholes.tif")

# Test --min/--max
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--pattern fill:left=0,0,0:right=1,1,1 64x64 3 "
                   + "--min -d uint8 -o min.exr")
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--pattern fill:left=0,0,0:right=1,1,1 64x64 3 "
                   + "--max -d uint8 -o max.exr")
# Test --minc/maxc val (min to all channels the same scalar)
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--minc 0.25 -o cmin1.exr")
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--maxc 0.75 -o cmax1.exr")
# Test --minc/maxc val,val,val... (min per-channel scalars)
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--minc 0.75,0.5,0.25 -o cmin2.exr")
command += oiiotool ("--pattern fill:top=0,0,0:bottom=1,1,1 64x64 3 "
                   + "--maxc 0.75,0.5,0.25 -o cmax2.exr")

# test --maxchan, --minchan
command += oiiotool ("--pattern fill:topleft=0,0,0.2:topright=1,0,0.2:bottomleft=0,1,0.2:bottomright=1,1,0.2 100x100 3 " +
                        " --maxchan -d uint8 -o maxchan.tif")
command += oiiotool ("--pattern fill:topleft=0,0,0.8:topright=1,0,0.8:bottomleft=0,1,0.8:bottomright=1,1,0.8 100x100 3 " +
                        " --minchan -d uint8 -o minchan.tif")

# test clamping
command += oiiotool ("../common/grid.tif --resize 50%"
            + " --clamp:min=0.2:max=,,0.5,1 -o grid-clamped.tif")

# test kernel
command += oiiotool ("--kernel bspline 15x15 -o bsplinekernel.exr")

# test convolve
command += oiiotool ("../common/tahoe-small.tif --kernel bspline 15x15 --convolve "
            + "-d uint8 -o bspline-blur.tif")

# test blur
command += oiiotool ("../common/tahoe-small.tif --blur 5x5 -d uint8 -o gauss5x5-blur.tif")

# test median filter
command += oiiotool ("../common/tahoe-small.tif --median 5x5 -d uint8 -o tahoe-median.tif")

# test dilate and erode
# command += oiiotool ("--pattern constant:color=0.1,0.1,0.1 80x64 3 --text:x=8:y=54:size=40:font=DroidSerif Aai -o morphsource.tif")
command += oiiotool ("src/morphsource.tif --dilate 3x3 -d uint8 -o dilate.tif")
command += oiiotool ("src/morphsource.tif --erode 3x3 -d uint8 -o erode.tif")
# command += oiiotool ("morphsource.tif --erode 3x3 --dilate 3x3 -d uint8 -o morphopen.tif")
# command += oiiotool ("morphsource.tif --dilate 3x3 --erode 3x3 -d uint8 -o morphclose.tif")
# command += oiiotool ("morphsource.tif morphopen.tif -sub -d uint8 -o tophat.tif")
# command += oiiotool ("morphclose.tif morphsource.tif -sub -d uint8 -o bottomhat.tif")

# test unsharp mask
command += oiiotool ("../common/tahoe-small.tif --unsharp -d uint8 -o unsharp.tif")

# test unsharp mask with median filter
command += oiiotool ("../common/tahoe-small.tif --unsharp:kernel=median -d uint8 -o unsharp-median.tif")

# test laplacian
command += oiiotool ("../common/tahoe-tiny.tif --laplacian -d uint8 -o tahoe-laplacian.tif")

# test fft, ifft
command += oiiotool ("../common/tahoe-tiny.tif --ch 2 --fft -d float -o fft.exr")
command += oiiotool ("fft.exr --ifft --ch 0 -d float -o ifft.exr")

# test --polar, --unpolar
# note that fft.exr that we built above is in complex form
command += oiiotool ("fft.exr --polar -d float -o polar.exr")
command += oiiotool ("polar.exr --unpolar -d float -o unpolar.exr")

# test labels
command += oiiotool (
            " --pattern constant:color=0.5,0.0,0.0 128x128 3 --label R " +
            " --pattern constant:color=0.0,0.5,0.0 128x128 3 --label G " +
            " --pattern constant:color=0.5,0.0,0.0 128x128 3 --label B " +
            " --pop --pop --pop " +
            " R G --add -d half -o labeladd.exr")

# test subimages
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 " +
                     "--siappend -d half -o subimages-2.exr")
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 --text A -attrib oiio:subimagename layerA " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 --text B -attrib oiio:subimagename layerB " +
                     "--pattern constant:color=0.0,0.0,0.5 64x64 3 --text C -attrib oiio:subimagename layerC " +
                     "--pattern constant:color=0.5,0.5,0.0 64x64 3 --text D -attrib oiio:subimagename layerD " +
                     "--siappendall -d half -o subimages-4.exr")
command += oiiotool ("subimages-4.exr --subimage 3 -o subimageD3.exr")
command += oiiotool ("subimages-4.exr --subimage layerB -o subimageB1.exr")
command += oiiotool ("subimages-4.exr --subimage:delete=1 layerB -o subimage-noB.exr")
command += oiiotool ("subimages-2.exr --sisplit -o subimage2.exr " +
                     "--pop -o subimage1.exr")
command += oiiotool ("subimages-4.exr -cmul:subimages=0,2 0.5 -o subimage-individual.exr")

# Test --printstats
command += oiiotool ("../common/tahoe-tiny.tif --echo \"--printstats:\" --printstats:native=1")
command += oiiotool ("../common/tahoe-tiny.tif --printstats:natve=1:window=10x10+50+50 --echo \" \"")

# test --iconfig
command += oiiotool ("--info -v -metamatch Debug --iconfig oiio:DebugOpenConfig! 1 " +
                     "--iconfig:type=float oiio:DebugOpenConfigInt! 2 " +
                     "--iconfig:type=float oiio:DebugOpenConfigFloat! 3 " +
                     "--iconfig:type=string oiio:DebugOpenConfigStr! 4 " +
                     "black.tif")

# test -i:ch=...
command += oiiotool ("--pattern fill:color=.6,.5,.4,.3,.2 64x64 5 -d uint8 -o const5.tif")
command += oiiotool ("-i:ch=R,G,B const5.tif -o const5-rgb.tif")

# Test that combining two images, if the first has no alpha but the second
# does, gets the right channel names instead of just copying from the first.
command += oiiotool ("-pattern constant:color=1,0,0 64x64 3 -pattern constant:color=0,1,0,1 64x64 4 -add -o add_rgb_rgba.exr")
command += info_command ("add_rgb_rgba.exr", safematch=True)

# Test --missingfile
command += oiiotool ("--create 320x240 4 --box:color=1,0,0,1:fill=1  10,10,200,100 -d uint8 -o box.tif")
# Test again using --missingfile black
command += oiiotool ("--missingfile black box.tif missing.tif --over -o box_over_missing2.tif || true")
# Test again using --missingfile checker
command += oiiotool ("--missingfile checker box.tif missing.tif --over -o box_over_missing3.tif || true")

# Test --dumpdata
command += oiiotool ("--pattern fill:left=0,0,0:right=1,1,0 2x2 3 -d half -o dump.exr")
command += oiiotool ("-echo dumpdata: --dumpdata dump.exr")
command += oiiotool ("-echo dumpdata:C --dumpdata:C=data dump.exr")

# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [
            "filled.tif",
            "autotrim.tif",
            "trim.tif", "trimsubimages.tif",
            "add.exr", "cadd1.exr", "cadd2.exr",
            "sub.exr", "subc.exr",
            "mul.exr", "cmul1.exr", "cmul2.exr",
            "div.exr", "divc1.exr", "divc2.exr",
            "mad.exr", "invert.tif",
            "cpow1.exr", "cpow2.exr",
            "normalize.exr", "normalize_scale.exr", "normalize_offsetin.exr",
            "normalize_offsetscaleout.exr", "normalize_offsetscale.exr",
            "abs.exr", "absdiff.exr", "absdiffc.exr",
            "chsum.tif",
            "tahoe-filled.tif", "growholes.tif",
            "rangecompress.tif", "rangeexpand.tif",
            "rangecompress-luma.tif", "rangeexpand-luma.tif",
            "min.exr", "cmin1.exr", "cmin2.exr",
            "max.exr", "cmax1.exr", "cmax2.exr",
            "maxchan.tif", "minchan.tif",
            "grid-clamped.tif",
            "bsplinekernel.exr", "bspline-blur.tif",
            "gauss5x5-blur.tif", "tahoe-median.tif",
            "dilate.tif", "erode.tif",
            "unsharp.tif", "unsharp-median.tif", "tahoe-laplacian.tif",
            "fft.exr", "ifft.exr",
            "polar.exr", "unpolar.exr",
            "subimages-2.exr",
            "subimages-4.exr",
            "subimageD3.exr",
            "subimageB1.exr",
            "subimage-noB.exr",
            "subimage-individual.exr",
            "subimage1.exr",
            "labeladd.exr",
            "const5-rgb.tif",
            "box_over_missing2.tif",
            "box_over_missing3.tif",
            "out.txt" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

from __future__ import print_function
from __future__ import absolute_import


############################################################################
# This file contains code examples from the ImageBufAlgo chapter of the
# main OpenImageIO documentation.
#
# To add an additional test, replicate the section below. Change
# "example1" to a helpful short name that identifies the example.


# BEGIN-imagebufalgo-example1
import OpenImageIO as oiio
from OpenImageIO import *
import numpy as np

def example1() :
    #
    # Example code fragment from the docs goes here.
    #
    # It probably should generate either some text output (which will show up
    # in "out.txt" that captures each test's output), or it should produce a
    # (small) image file that can be compared against a reference image that
    # goes in the ref/ subdirectory of this test.
    #
    return

# END-imagebufalgo-example1

#
############################################################################


# Section: ImageBufAlgo common principles

def example_output_error1():
    fg = ImageBuf()
    bg = ImageBuf()

    # BEGIN-imagebufalgo-output-error1
    # Method 1: Return an image result
    dst = ImageBufAlgo.over(fg, bg)
    if dst.has_error:
        print("error:", dst.geterror())
    # END-imagebufalgo-output-error1


def example_output_error2():
    fg = ImageBuf()
    bg = ImageBuf()

    # BEGIN-imagebufalgo-output-error2
    # Method 2: Write into an existing image
    dst = ImageBuf()  # will be the output image
    ok = ImageBufAlgo.over(dst, fg, bg)
    if not ok:
        print("error:", dst.geterror())
    # END-imagebufalgo-output-error2


# Section: Pattern Generation

def example_zero():
    A = ImageBuf("grid.exr")
    B = ImageBuf("grid.exr")
    C = ImageBuf("grid.exr")

    # BEGIN-imagebufalgo-zero
    # Create a new 3-channel, 512x512 float image filled with 0.0 values.
    zero = ImageBufAlgo.zero(ROI(0, 512, 0, 512, 0, 1, 0, 3))

    # Zero out an existing buffer, keeping it the same size and data type
    ImageBufAlgo.zero(A)

    # Zero out just the green channel, leave everything else the same
    roi = B.roi
    roi.chbegin = 1 # green
    roi.chend = 2   # one past the end of the channel region
    ImageBufAlgo.zero(B, roi)

    # Zero out a rectangular region of an existing buffer
    ImageBufAlgo.zero(C, ROI(0, 100, 0, 100))
    # END-imagebufalgo-zero

    zero.write("zero1.exr")
    A.write("zero2.exr")
    B.write("zero3.exr")
    C.write("zero4.exr")


def example_fill():
    # BEGIN-imagebufalgo-fill
    # Create a new 640x480 RGB image, with a top-to-bottom gradient
    # from red to pink
    pink = (1, 0.7, 0.7)
    red = (1, 0, 0)
    A = ImageBufAlgo.fill(top=red, bottom=pink,
                          roi=ROI(0, 640, 0, 480, 0, 1, 0, 3))

    # Draw a filled red rectangle overtop existing image A.
    ImageBufAlgo.fill(A, red, ROI(50, 100, 75, 175))
    # END-imagebufalgo-fill

    A.write("fill.exr")


def example_checker():
    # BEGIN-imagebufalgo-checker
    # Create a new 640x480 RGB image, fill it with a two-toned gray
    # checkerboard, the checkers being 64x64 pixels each.
    A = ImageBuf(ImageSpec(640, 480, 3, "float"))
    dark = (0.1, 0.1, 0.1)
    light = (0.4, 0.4, 0.4)
    A = ImageBufAlgo.checker(64, 64, 1, dark, light,
                             roi=ROI(0, 640, 0, 480, 0, 1, 0, 3))
    # END-imagebufalgo-checker

    A.write("checker.exr")


def example_noise1():
    # BEGIN-imagebufalgo-noise1
    # Create a new 256x256 field of grayscale white noise on [0,1)
    A = ImageBufAlgo.noise("uniform", A=0.0, B=1.0, mono=True, seed=1,
                           roi=ROI(0, 256, 0, 256, 0, 1, 0, 3))

    # Create a new 256x256 field of grayscale blue noise on [0,1)
    B = ImageBufAlgo.noise("blue", A=0.0, B=1.0, mono=True, seed=1,
                           roi=ROI(0, 256, 0, 256, 0, 1, 0, 3))

    # Add color Gaussian noise to an existing image
    C = ImageBuf("tahoe.tif")
    ImageBufAlgo.noise(C, "gaussian", A=0.0, B=0.1, mono=False, seed=1)

    # Use salt and pepper noise to make occasional random dropouts
    D = ImageBuf("tahoe.tif")
    ImageBufAlgo.noise(D, "salt", A=0.0, B=0.01, mono=True, seed=1)
    # END-imagebufalgo-noise1

    A.write("noise1.exr")
    B.write("noise2.exr")
    C.write("noise3.exr")
    D.write("noise4.exr")


def example_noise2():
    # BEGIN-imagebufalgo-noise2
    A = ImageBufAlgo.bluenoise_image()
    # END-imagebufalgo-noise2

    A.write("blue-noise.exr")


def example_point():
    # BEGIN-imagebufalgo-point
    A = ImageBuf(ImageSpec(640, 480, 4, "float"))
    red = (1, 0, 0, 1)
    ImageBufAlgo.render_point(A, 50, 100, red)
    # END-imagebufalgo-point

    A.write("point.exr")


def example_lines():
    # BEGIN-imagebufalgo-lines
    A = ImageBuf(ImageSpec(640, 480, 4, "float"))
    red = (1, 0, 0, 1)
    ImageBufAlgo.render_line(A, 10, 60, 250, 20, red)
    ImageBufAlgo.render_line(A, 250, 20, 100, 190, red, True)
    # END-imagebufalgo-lines

    A.write("lines.exr")


def example_box():
    # BEGIN-imagebufalgo-box
    A = ImageBuf(ImageSpec(640, 480, 4, "float"))
    cyan = (0, 1, 1, 1)
    yellow_transparent = (0.5, 0.5, 0, 0.5)
    ImageBufAlgo.render_box(A, 150, 100, 240, 180, cyan)
    ImageBufAlgo.render_box(A, 100, 50, 180, 140, yellow_transparent, fill=True)
    # END-imagebufalgo-box

    A.write("box.exr")


def example_text1():
    ImgA = ImageBufAlgo.zero(ROI(0, 640, 0, 480, 0, 1, 0, 3))
    ImgB = ImageBufAlgo.zero(ROI(0, 640, 0, 480, 0, 1, 0, 3))

    # BEGIN-imagebufalgo-text1
    ImageBufAlgo.render_text(ImgA, 50, 100, "Hello, world")
    red = (1, 0, 0, 1)
    ImageBufAlgo.render_text(ImgA, 100, 200, "Go Big Red!",
                             fontsize=60, fontname="", textcolor=red)

    white = (1, 1, 1, 1)
    ImageBufAlgo.render_text(ImgB, 320, 240, "Centered",
                             fontsize=60, fontname="", textcolor=white,
                             alignx="center", aligny="center")
    # END-imagebufalgo-text1

    ImgA.write("text1.exr")
    ImgB.write("text2.exr")


def example_test2():
    # BEGIN-imagebufalgo-text2
    # Render text centered in the image, using text_size to find out
    # the size we will need and adjusting the coordinates.
    A = ImageBuf(ImageSpec(640, 480, 4, "float"))
    Aroi = A.roi
    size = ImageBufAlgo.text_size("Centered", 48, "Courier New")
    if size.defined:
        x = Aroi.xbegin + Aroi.width//2 - (size.xbegin + size.width//2)
        y = Aroi.ybegin + Aroi.height//2 - (size.ybegin + size.height//2)
        ImageBufAlgo.render_text(A, x, y, "Centered", 48, "Courier New")
    # END-imagebufalgo-text2


# Section: Image transformation and data movement

def example_circular_shift() :
    # BEGIN-imagebufalgo-cshift
    A = ImageBuf("grid.exr")
    B = ImageBufAlgo.circular_shift(A, 70, 30)
    # END-imagebufalgo-cshift
    B.write("cshift.exr")


# Section: Image Arithmetic


# Section: Image comparison and statistics


# Section: Convolution and frequency-space algorithms


# Section: Image enhancement / restoration


# Section: Morphological filters


# Section: Color space conversion


# Section: Import / export

def example_make_texture():
    # BEGIN-imagebufalgo-make-texture
    Input = ImageBuf("grid.exr")
    config = ImageSpec()
    config["maketx:highlightcomp"] = 1
    config["maketx:filtername"] = "lanczos3"
    config["maketx:opaque_detect"] = 1

    ok = ImageBufAlgo.make_texture (oiio.MakeTxTexture,
                                    Input, "texture.exr", config)
    if not ok :
        print("make_texture error:", oiio.geterror())

    # END-imagebufalgo-make-texture






if __name__ == '__main__':
    # Each example function needs to get called here, or it won't execute
    # as part of the test.
    example1()

    # Section: ImageBufAlgo common principles
    example_output_error1()
    example_output_error2()

    # Section: Pattern Generation
    example_zero()
    example_fill()
    example_checker()
    example_noise1()
    example_noise2()
    example_point()
    example_lines()
    example_box()
    example_text1()
    example_test2()

    # Section: Image transformation and data movement
    example_circular_shift()

    # Section: Image Arithmetic

    # Section: Image comparison and statistics

    # Section: Convolution and frequency-space algorithms

    # Section: Image enhancement / restoration

    # Section: Morphological filters

    # Section: Color space conversion

    # Section: Import / export
    example_make_texture()



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# save the error output
redirect = " >> out.txt 2>&1 "
failureok = 1

command += rw_command (OIIO_TESTSUITE_IMAGEDIR + "/broken",
                       "invalid_gray_alpha_sbit.png",
                       printinfo=False)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Allow some LSB slop -- necessary because of the alpha disassociation
# combined with implied sRGB conversion.
failthresh = 0.02
failpercent = 0.02

# ../j2kp4files_v1_5/testfiles_jp2
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/testfiles_jp2"
files = [ "file1.jp2", "file2.jp2", "file3.jp2","file4.jp2",
          "file5.jp2", "file6.jp2", "file7.jp2","file8.jp2",
          "file9.jp2" ]
for f in files:
    command += rw_command (imagedir, f)

# ../j2kp4files_v1_5/codestreams_profile0:
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/codestreams_profile0"
files = [ "p0_01.j2k", "p0_02.j2k",
          #"p0_03.j2k",
          "p0_04.j2k",
          "p0_05.j2k", "p0_06.j2k", 
          # "p0_07.j2k",  # can't decode for some reason
          "p0_08.j2k", 
          "p0_09.j2k", "p0_10.j2k", "p0_11.j2k", "p0_12.j2k",
          # "p0_13.j2k",    # can't decode
          "p0_14.j2k", "p0_15.j2k" ]
# for f in files:
#     command += rw_command (imagedir, f)
# Skip these for now, for the sake of a faster unit test. Re-enable it
# later if we speed up the jpeg2000 reader.

# ../j2kp4files_v1_5/codestreams_profile1:
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/codestreams_profile1"
files = [ "p1_01.j2k", "p1_02.j2k", "p1_03.j2k", "p1_04.j2k",
          "p1_05.j2k", "p1_06.j2k", "p1_07.j2k" ]
# for f in files:
#     command += rw_command (imagedir, f)
# Skip these for now, for the sake of a faster unit test. Re-enable it
# later if we speed up the jpeg2000 reader.



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


redirect = " >> out.txt 2>&1"
failureok = True

command += oiiotool ("src/bad.exr --fixnan black -o black.exr")
command += oiiotool ("src/bad.exr --fixnan box3 -o box3.exr")
command += oiiotool ("src/bad.exr --fixnan error -o err.exr")
command += info_command ("src/bad.exr", "--stats", safematch=True)
command += info_command ("black.exr", "--stats", safematch=True)
command += info_command ("box3.exr", "--stats", safematch=True)

# test deep
command += oiiotool ("src/bad.exr --chnames R,A,Z --deepen -o deep.exr")
command += oiiotool ("deep.exr --echo \"Bad deep (black):\" --printstats" +
                     " --fixnan black --printstats --echo \" \"")
command += oiiotool ("deep.exr --echo \"Bad deep (box3):\" --printstats" +
                     " --fixnan box3 --printstats --echo \" \"")
command += oiiotool ("deep.exr --echo \"Bad deep (error):\" --printstats" +
                     " --fixnan error --printstats --echo \" \"")

# Outputs to check against references
outputs = [ "black.exr", "box3.exr", "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Make two images that differ by a particular known pixel value
command += oiiotool("-pattern fill:color=0.1,0.1,0.1 64x64 3 -d float -o img1.exr")
command += oiiotool("-pattern fill:color=0.1,0.1,0.1 64x64 3 -d float -box:fill=1:color=0.1,0.6,0.1 5,17,15,27 -o img2.exr")

# Now make sure idiff and oiiotool --diff print the right info
failureok = True
command += diff_command("img1.exr", "img2.exr")
command += oiiotool("--diff img1.exr img2.exr")

# --pdiff
command += oiiotool("-pdiff img1.exr img2.exr")
command += oiiotool("-pdiff img1.exr img1.exr")
command += diff_command("img1.exr", "img2.exr", extraargs="-p")
command += diff_command("img1.exr", "img1.exr", extraargs="-p")
command += diff_command("img1.exr", "img2.exr", extraargs="-p -fail 1")


# Outputs to check against references
outputs = [ "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


imagedir = "ref/"
command += oiiotool ("-pattern fill:topleft=0.1:topright=0.5:bottomleft=1.0:bottomright=0.3 64x64 1 -chnames Z -d float -o out.zfile")
command += info_command ("out.zfile", extraargs="-stats")

outputs = [ "out.zfile", "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

# Test reading and writing of files with per-channel data formats.


# Few image formats support per-channel formats, but OpenEXR is one
# of them, and the OpenEXR test images contains one such image:
image = OIIO_TESTSUITE_IMAGEDIR + "/ScanLines/Blobbies.exr"

# iconvert reads and writes native format, test that.
command += (oiio_app("iconvert") + image + " blob1.exr ;\n")
command += diff_command (image, "blob1.exr")

# oiiotool uses a different code path involving ImageCache and ImageBuf,
# and will convert to float along the way.
command += (oiio_app("oiiotool") + image + " -o blob2.exr ;\n")
command += diff_command (image, "blob2.exr")


# Now we do a similar test for a tiled OpenEXR file with per-channel formats
image = OIIO_TESTSUITE_IMAGEDIR + "/Tiles/Spirals.exr"

# iconvert reads and writes native format, test that.
command += (oiio_app("iconvert") + image + " spiral1.exr ;\n")
command += diff_command (image, "spiral1.exr")

# oiiotool uses a different code path involving ImageCache and ImageBuf,
# and will convert to float along the way.
command += (oiio_app("oiiotool") + image + " -o spiral2.exr ;\n")
command += diff_command (image, "spiral2.exr")

# Create a file with per-channel data types, make sure that works
command += oiiotool("--create 64x64 4 --d R=half,G=float,B=half,A=float -o hfhf.exr")
command += info_command("hfhf.exr", verbose=False)

# Make sure that read/write unmodified will preserve the channel types
command += oiiotool("hfhf.exr -o hfhf_copy.exr")
command += info_command("hfhf_copy.exr", verbose=False)

# Make sure that read/modify/write preserves the channel types of the input
command += oiiotool("hfhf.exr -mulc 0.5,0.5,0.5,0.5 -o hfhf_mod.exr")
command += info_command("hfhf_mod.exr", verbose=False)

#print "Running this command:\n" + command + "\n"




#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command = testtex_command ("--gettexels -res 128 128 -d uint8 ../common/textures/grid.tx -o postage.tif")
outputs = [ "postage.tif" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


redirect = ">> out.txt 2>&1"
# Create a ramped checker
command += oiiotool("-pattern fill:topleft=0,0,0,1:topright=1,0,0,1:bottomleft=0,1,0,1:bottomright=1,1,0,1 256x128 4 "
                    "-pattern checker:color1=1,1,1,1:color2=0.5,0.5,0.5,1:width=16:height=16 256x128 4 -mul "
                    "-attrib DateTime \"2022-11-11 11:11:11\" -attrib oiio:subimagename Fred "
                    "-d half -oenv rampenv.exr")

command += testtex_command("--res 64 32 -d half -o env.exr rampenv.exr")

# This time, use handles, exercise derivatives
command += testtex_command("--handle --derivs --no-gettextureinfo "
                           "--res 64 32 -d half -o env-handle.exr rampenv.exr")

# more channels
command += oiiotool("-pattern fill:topleft=0,0,0,1,1:topright=1,0,0,1,1:bottomleft=0,1,0,1,1:bottomright=1,1,0,1,1 256x128 5 "
                    "-pattern checker:color1=1,1,1,1,1:color2=0.5,0.5,0.5,1,0.5:width=16:height=16 256x128 5 -mul "
                    "-attrib DateTime \"2022-11-11 11:11:11\" -d half -oenv env5chan.exr")
command += testtex_command("--nchannels 5 --derivs --no-gettextureinfo --res 64 32 -d half -o 5chan.exr env5chan.exr")

# subimages
command += testtex_command("--nchannels 4 --no-gettextureinfo -subimage 0 --res 64 32 -d half -o subimage0.exr rampenv.exr")
command += testtex_command("--nchannels 4 --no-gettextureinfo -subimagename Fred --res 64 32 -d half -o subimagefred.exr rampenv.exr")
command += testtex_command("--nchannels 4 --no-gettextureinfo -subimagename missing --res 2 1 -d half -o subimagemissing.exr rampenv.exr")

# interp and mip modes
command += testtex_command("-interpmode 0 -mipmode 1 --no-gettextureinfo --res 64 32 -d half -o closest-nomip.exr rampenv.exr")
command += testtex_command("-interpmode 1 -mipmode 2 --no-gettextureinfo --res 64 32 -d half -o bilinear-onelevel.exr rampenv.exr")
command += testtex_command("-interpmode 2 -mipmode 3 --no-gettextureinfo --res 64 32 -d half -o bicubic-trilinear.exr rampenv.exr")

outputs = [ "env.exr",
            "env-handle.exr",
            "5chan.exr",
            "subimage0.exr",
            "subimagefred.exr",
            "subimagemissing.exr",
            "closest-nomip.exr",
            "bilinear-onelevel.exr",
            "bicubic-trilinear.exr",
            "out.txt" ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


# Slightly bump allowable failures, for slightly shifting font rendering
# with changed freetype versions.
failpercent *= 2.0

redirect = " >> out.txt 2>&1 "
failureok = 1

# test subimages
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 " +
                     "--siappend -d half -o subimages-2.exr")
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 --text A -attrib oiio:subimagename layerA " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 --text B -attrib oiio:subimagename layerB " +
                     "--pattern constant:color=0.0,0.0,0.5 64x64 3 --text C -attrib oiio:subimagename layerC " +
                     "--pattern constant:color=0.5,0.5,0.0 64x64 3 --text D -attrib oiio:subimagename layerD " +
                     "--siappendall -d half -o subimages-4.exr")
command += oiiotool ("subimages-4.exr --subimage 3 -o subimageD3.exr")
command += oiiotool ("subimages-4.exr --subimage layerB -o subimageB1.exr")
command += oiiotool ("subimages-2.exr --sisplit -o:all=1 subimage%d.exr")

# test that we can set attributes on individual subimages
command += oiiotool ("subimages-4.exr --attrib:subimages=0 Beatle John --attrib:subimages=1 Beatle Paul --attrib:subimages=2 Beatle George --attrib:subimages=3 Beatle Ringo -o gpgr.exr")
command += info_command ("-a -v gpgr.exr", safematch=1)

# Test extraction of MIP levels
command += oiiotool ("../common/textures/grid.tx --selectmip 4 -o mip4.tif")
command += info_command ("mip4.tif", safematch=True)
command += oiiotool ("../common/textures/grid.tx --unmip -o unmip.tif")
command += info_command ("../common/textures/grid.tx", verbose=False)
command += info_command ("unmip.tif", verbose=False)

# Error cases
command += oiiotool ("-echo \"Select nonexistent subimage\""
                     + " subimages-4.exr --subimage 13 -o subimage13.exr")
command += oiiotool ("-echo \"Select nonexistent MIP level\""
                     + " ../common/textures/grid.tx --selectmip 14 -o mip14.tif")

# Outputs to check against references
outputs = [ 
            "subimages-2.exr", "subimages-4.exr",
            "subimage1.exr", "subimage2.exr",
            "subimageD3.exr", "subimageB1.exr",
            "mip4.tif",
            "out.txt"
          ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

command = (oiio_app("testtex") + " -res 256 256 --nowarp "
           + OIIO_TESTSUITE_IMAGEDIR + "/miplevels.tx"
           + " -o out.tif ;\n")
command += diff_command ("out.tif", "ref/out.tif", "--fail 0.0005 --warn 0.0005")

outputs = [ ]



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO

command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/grid.tif --scanline -o gridscanline.iff")
command += diff_command (OIIO_TESTSUITE_IMAGEDIR+"/grid.tif", "gridscanline.iff")
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/grid.tif --tile 64 64 -o gridtile.iff")
command += diff_command (OIIO_TESTSUITE_IMAGEDIR+"/grid.tif", "gridtile.iff")



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: Apache-2.0
# https://github.com/AcademySoftwareFoundation/OpenImageIO


command = testtex_command ("src/horizgrid.tx", " --scalest 1 4")
outputs = [ "out.exr" ]
